# coding:utf-8
from __future__ import print_function

from volcengine.visual.VisualService import VisualService

if __name__ == '__main__':
    visual_service = VisualService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    visual_service.set_ak('ak')
    visual_service.set_sk('sk')
    # visual_service.set_host('host')

    # below shows the sdk usage for all common apis,
    # if you cannot find the needed one, please check other example files in the same dir
    # or contact us for further help
    form = dict()
    form["image_base64"] = "image_base64_str"

    # 车牌检测
    # resp = visual_service.car_plate_detection(form)

    # 人像畸变矫正
    # resp = visual_service.distortion_free(form)

    # 图片拉伸修复
    # resp = visual_service.stretch_recovery(form)

    # 图片流动
    # form["motion_ratio"] = 2
    # resp = visual_service.image_flow(form)

    # 图片评分
    # resp = visual_service.image_score(form)

    # 图片配文
    # resp = visual_service.poem_material(form)

    # 表情编辑
    # form["service_choice"] = 0
    # resp = visual_service.emoticon_edit(form)

    # 闭眼转睁眼
    # resp = visual_service.eye_close2open(form)

    # 车辆分割
    # resp = visual_service.car_segment(form)

    # 车辆检测
    # resp = visual_service.car_detection(form)

    # 天空分割
    # resp = visual_service.sky_segment(form)

    # 老照片修复
    # resp = visual_service.convert_photo(form)

    # 图像增强
    # resp = visual_service.enhance_photo(form)

    # 通用分割
    # resp = visual_service.general_segment(form)

    # 人体分割
    # form["refine"] = 0
    # form["return_foreground_image"] = 0
    # resp = visual_service.human_segment(form)

    # 人像漫画风
    # form["cartoon_type"] = "jpcartoon_head"
    # form["rotation"] = 0 # this param is valid only when cartoon_type == jpcartoon_head
    # resp = visual_service.jpcartoon(form)

    # 人脸融合
    # form["template_base64"] = "template_base64_str"
    # form["action_id"] = "faceswap"
    # resp = visual_service.face_swap(form)

    # 通用OCR
    # resp = visual_service.ocr_normal(form)

    # 身份证OCR
    # resp = visual_service.id_card(form)

    # 银行卡OCR
    # resp = visual_service.bank_card(form)

    # 营业执照OCR
    # resp = visual_service.clue_license(form)

    # 驾驶证OCR
    # resp = visual_service.driving_license(form)

    # 行驶证OCR
    # resp = visual_service.vehicle_license(form)

    # 出租车票OCR
    # resp = visual_service.taxi_invoice(form)

    # 火车票OCR
    # resp = visual_service.train_ticket(form)

    # 行程单OCR
    # resp = visual_service.flight_invoice(form)

    # 增值税发票OCR
    # resp = visual_service.vat_invoice(form)

    # 定额发票OCR
    # resp = visual_service.quota_invoice(form)

    # 发型编辑
    # resp = visual_service.hair_style(form)

    # 智能变美
    # resp = visual_service.face_pretty(form)

    # 活照片
    # resp = visual_service.image_animation(form)

    # 视频选封面
    # resp = visual_service.cover_video(form)

    # 希区柯克
    # resp = visual_service.dolly_zoom(form)

    # 人像特效
    # resp = visual_service.potrait_effect(form)

    # 图像风格转换
    # resp = visual_service.image_style_conversion(form)

    # 3d游戏风
    # resp = visual_service.three_d_game_cartoon(form)

    # 头发抠图
    # resp = visual_service.hair_segment(form)
    # form["mode"] = 0
    # form["refine_mask"] = 0
    # form["flip_test"] = 0

    # 印章识别
    # resp = visual_service.ocr_seal(form)

    # pdf识别
    # resp = visual_service.ocr_pdf(form)

    # 高速公路过路费
    # resp = visual_service.ocr_pass_invoice(form)

    # 商标证
    # resp = visual_service.ocr_trade(form)

    # 软件著作权
    # resp = visual_service.ocr_ruanzhu(form)

    # 化妆品生产许可证
    # resp = visual_service.ocr_cosmetic_product(form)

    # 表格识别
    # resp = visual_service.ocr_table(form)
    print(resp)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    update_task_body = {
        "TaskOpenId": "106d2984fbf0480480cbc8b98d609592",
        "Concurrency": 3,
        "StartTime": "2022-03-02 00:00:00",
        "EndTime": "2022-03-13 01:30:00",
        "Recall": 1
    }

    print(notify_service.update_task(update_task_body))



# coding:utf-8
import json
import os

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service
from volcengine.const.Const import *
from volcengine.Policy import *
import aiohttp
from volcengine.auth.SignerV4 import SignerV4

LIVESAAS_SERVICE_NAME = "livesaas"
LIVESAAS_API_VERSION = "2020-06-01"

service_info_map = {
    REGION_CN_NORTH1: ServiceInfo(
        "livesaas.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', LIVESAAS_SERVICE_NAME, REGION_CN_NORTH1),
        5, 5, "https"),
}

api_info = {
    # 直播间管理类接口
    "CreateActivityAPI":
        ApiInfo("POST", "/", {"Action": "CreateActivityAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "DeleteActivityAPI":
        ApiInfo("POST", "/", {"Action": "DeleteActivityAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "ListActivityAPI":
        ApiInfo("GET", "/", {"Action": "ListActivityAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    # 直播控制类接口
    "UpdateActivityStatusAPI":
        ApiInfo("POST", "/", {"Action": "UpdateActivityStatusAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "UpdatePullToPushAPI":
        ApiInfo("POST", "/", {"Action": "UpdatePullToPushAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "GetActivityAPI":
        ApiInfo("GET", "/", {"Action": "GetActivityAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "GetStreamsAPI":
        ApiInfo("GET", "/", {"Action": "GetStreamsAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "UpdateActivityBasicConfigAPI":
        ApiInfo("POST", "/", {"Action": "UpdateActivityBasicConfigAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "GetActivityBasicConfigAPI":
        ApiInfo("GET", "/", {"Action": "GetActivityBasicConfigAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "UpdateLoopVideoAPI":
        ApiInfo("POST", "/", {"Action": "UpdateLoopVideoAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "UpdateLoopVideoStatusAPI":
        ApiInfo("POST", "/", {"Action": "UpdateLoopVideoStatusAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    # 回放管理类接口
    "UploadReplayAPI":
        ApiInfo("POST", "/", {"Action": "UploadReplayAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "UpdateMediaOnlineStatusAPI":
        ApiInfo("POST", "/", {"Action": "UpdateMediaOnlineStatusAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "ListMediasAPI":
        ApiInfo("GET", "/", {"Action": "ListMediasAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    # 评论类接口
    "PresenterChatAPI":
        ApiInfo("POST", "/", {"Action": "PresenterChatAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    "DeleteChatAPI":
        ApiInfo("POST", "/", {"Action": "DeleteChatAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
    # 客户端SDK类接口
    "GetSDKTokenAPI":
        ApiInfo("POST", "/", {"Action": "GetSDKTokenAPI", "Version": LIVESAAS_API_VERSION}, {}, {}),
}


class LivesaasService(Service):
    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = LivesaasService.get_service_info(region)
        self.api_info = LivesaasService.get_api_info()
        super(LivesaasService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('LivesaasService not support region %s' % region)
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    async def async_json(self, api, params, body):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]
        r = self.prepare_request(api_info, params)
        r.headers['Content-Type'] = 'application/json'
        r.body = body
        timeout = aiohttp.ClientTimeout(connect=self.service_info.connection_timeout, sock_connect=self.service_info.socket_timeout)

        SignerV4.sign(r, self.service_info.credentials)

        url = r.build()
        async with aiohttp.request("POST", url, headers=r.headers, data=r.body, timeout=timeout) as r:
            resp = await r.text(encoding="utf-8")
            if r.status == 200:
                return resp
            else:
                raise Exception(resp)

    async def async_get(self, api, params):
        if not (api in self.api_info):
            raise Exception("no such api")
        api_info = self.api_info[api]
        r = self.prepare_request(api_info, params)
        timeout = aiohttp.ClientTimeout(connect=self.service_info.connection_timeout, sock_connect=self.service_info.socket_timeout)

        SignerV4.sign(r, self.service_info.credentials)

        url = r.build()
        async with aiohttp.request("GET", url, headers=r.headers, timeout=timeout) as r:
            resp = await r.text(encoding="utf-8")
            if r.status == 200:
                return resp
            else:
                raise Exception(resp)

    # ========================= 直播间管理类接口 =========================
    # CreateActivityAPI
    def create_activity_api(self, body):
        res = self.json('CreateActivityAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("CreateActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_create_activity_api(self, body):
        res = await self.async_json('CreateActivityAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("CreateActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # DeleteActivityAPI
    def delete_activity_api(self, body):
        res = self.json('DeleteActivityAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("DeleteActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_delete_activity_api(self, body):
        res = await self.async_json('DeleteActivityAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("DeleteActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ListActivityAPI
    def list_activity_api(self, params):
        res = self.get('ListActivityAPI', params)
        if res == '':
            raise Exception("ListActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_list_activity_api(self, params):
        res = await self.async_get('ListActivityAPI', params)
        if res == '':
            raise Exception("ListActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ========================= 直播间控制类接口 =========================
    # UpdateActivityStatusAPI
    def update_activity_status_api(self, body):
        res = self.json('UpdateActivityStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateActivityStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_activity_status_api(self, body):
        res = await self.async_json('UpdateActivityStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateActivityStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # UpdatePullToPushAPI
    def update_pull_to_push_api(self, body):
        res = self.json('UpdatePullToPushAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdatePullToPushAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_pull_to_push_api(self, body):
        res = await self.async_json('UpdatePullToPushAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdatePullToPushAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # GetActivityAPI
    def get_activity_api(self, params):
        res = self.get('GetActivityAPI', params)
        if res == '':
            raise Exception("GetActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_get_activity_api(self, params):
        res = await self.async_get('GetActivityAPI', params)
        if res == '':
            raise Exception("GetActivityAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # GetStreamsAPI
    def get_streams_api(self, params):
        res = self.get('GetStreamsAPI', params)
        if res == '':
            raise Exception("GetStreamsAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_get_streams_api(self, params):
        res = await self.async_get('GetStreamsAPI', params)
        if res == '':
            raise Exception("GetStreamsAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # UpdateActivityBasicConfigAPI
    def update_activity_basic_config_api(self, body):
        res = self.json('UpdateActivityBasicConfigAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateActivityBasicConfigAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_activity_basic_config_api(self, body):
        res = await self.async_json('UpdateActivityBasicConfigAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateActivityBasicConfigAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # GetActivityBasicConfigAPI
    def get_activity_basic_config_api(self, params):
        res = self.get('GetActivityBasicConfigAPI', params)
        if res == '':
            raise Exception("GetActivityBasicConfigAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_get_activity_basic_config_api(self, params):
        res = await self.async_get('GetActivityBasicConfigAPI', params)
        if res == '':
            raise Exception("GetActivityBasicConfigAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # UpdateLoopVideoAPI
    def update_loop_video_api(self, body):
        res = self.json('UpdateLoopVideoAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateLoopVideoAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_loop_video_api(self, body):
        res = await self.async_json('UpdateLoopVideoAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateLoopVideoAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # UpdateLoopVideoStatusAPI
    def update_loop_video_status_api(self, body):
        res = self.json('UpdateLoopVideoStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateLoopVideoStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_loop_video_status_api(self, body):
        res = await self.async_json('UpdateLoopVideoStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateLoopVideoStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ========================= 回放管理类接口 =========================
    # UploadReplayAPI
    def upload_replay_api(self, body):
        res = self.json('UploadReplayAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UploadReplayAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_upload_replay_api(self, body):
        res = await self.async_json('UploadReplayAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UploadReplayAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # UpdateMediaOnlineStatusAPI
    def update_media_online_status_api(self, body):
        res = self.json('UpdateMediaOnlineStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateMediaOnlineStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_update_media_online_status_api(self, body):
        res = await self.async_json('UpdateMediaOnlineStatusAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("UpdateMediaOnlineStatusAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ListMediasAPI
    def list_medias_api(self, params):
        res = self.get('ListMediasAPI', params)
        if res == '':
            raise Exception("ListMediasAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_list_medias_api(self, params):
        res = await self.async_get('ListMediasAPI', params)
        if res == '':
            raise Exception("ListMediasAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ========================= 评论类接口 =========================
    # PresenterChatAPI
    def presenter_chat_api(self, body):
        res = self.json('PresenterChatAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("PresenterChatAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_presenter_chat_api(self, body):
        res = await self.async_json('PresenterChatAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("PresenterChatAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # DeleteChatAPI
    def delete_chat_api(self, body):
        res = self.json('DeleteChatAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("DeleteChatAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_delete_chat_api(self, body):
        res = await self.async_json('DeleteChatAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("DeleteChatAPI: empty response")
        res_json = json.loads(res)
        return res_json

    # ========================= 客户端SDK类接口 =========================
    # GetSDKTokenAPI
    def get_sdk_token_api(self, body):
        res = self.json('GetSDKTokenAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("GetSDKTokenAPI: empty response")
        res_json = json.loads(res)
        return res_json

    async def async_get_sdk_token_api(self, body):
        res = await self.async_json('GetSDKTokenAPI', dict(), json.dumps(body))
        if res == '':
            raise Exception("GetSDKTokenAPI: empty response")
        res_json = json.loads(res)
        return res_json


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vod/business/vod_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dvod/business/vod_common.proto\x12\x1eVolcengine.Vod.Models.Business\"\x85\x02\n\rVodSourceInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\r\n\x05\x43odec\x18\x04 \x01(\t\x12\x0e\n\x06Height\x18\x05 \x01(\x05\x12\r\n\x05Width\x18\x06 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x07 \x01(\t\x12\x10\n\x08\x44uration\x18\x08 \x01(\x02\x12\x0c\n\x04Size\x18\t \x01(\x01\x12\x10\n\x08StoreUri\x18\n \x01(\t\x12\x12\n\nDefinition\x18\x0b \x01(\t\x12\x0f\n\x07\x42itrate\x18\x0c \x01(\x05\x12\x0b\n\x03\x46ps\x18\r \x01(\x02\x12\x12\n\nCreateTime\x18\x0e \x01(\t\x12\x0f\n\x07Quality\x18\x0f \x01(\t\"k\n\x12VodAudioStreamMeta\x12\r\n\x05\x43odec\x18\x01 \x01(\t\x12\x10\n\x08\x44uration\x18\x02 \x01(\x02\x12\x12\n\nSampleRate\x18\x03 \x01(\x05\x12\x0f\n\x07\x42itrate\x18\x04 \x01(\x05\x12\x0f\n\x07Quality\x18\x05 \x01(\t\"\x86\x01\n\x12VodVideoStreamMeta\x12\r\n\x05\x43odec\x18\x01 \x01(\t\x12\x0e\n\x06Height\x18\x02 \x01(\x05\x12\r\n\x05Width\x18\x03 \x01(\x05\x12\x10\n\x08\x44uration\x18\x04 \x01(\x02\x12\x12\n\nDefinition\x18\x05 \x01(\t\x12\x0f\n\x07\x42itrate\x18\x06 \x01(\x05\x12\x0b\n\x03\x46ps\x18\x07 \x01(\x02\"\xd4\x02\n\x10VodTranscodeInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\x10\n\x08LogoType\x18\x04 \x01(\t\x12\x0f\n\x07\x45ncrypt\x18\x05 \x01(\x08\x12\x0e\n\x06\x46ormat\x18\x06 \x01(\t\x12\x10\n\x08\x44uration\x18\x07 \x01(\x02\x12\x0c\n\x04Size\x18\x08 \x01(\x01\x12\x10\n\x08StoreUri\x18\t \x01(\t\x12K\n\x0fVideoStreamMeta\x18\n \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodVideoStreamMeta\x12K\n\x0f\x41udioStreamMeta\x18\x0b \x01(\x0b\x32\x32.Volcengine.Vod.Models.Business.VodAudioStreamMeta\x12\x12\n\nCreateTime\x18\x0c \x01(\t\"S\n\x0fVodAdaptiveInfo\x12\x13\n\x0bMainPlayUrl\x18\x01 \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x02 \x01(\t\x12\x14\n\x0c\x41\x64\x61ptiveType\x18\x03 \x01(\t\"\xa4\x03\n\x0bVodPlayInfo\x12\x0e\n\x06\x46ileId\x18\x01 \x01(\t\x12\x0b\n\x03Md5\x18\x02 \x01(\t\x12\x10\n\x08\x46ileType\x18\x03 \x01(\t\x12\x0e\n\x06\x46ormat\x18\x04 \x01(\t\x12\r\n\x05\x43odec\x18\x05 \x01(\t\x12\x12\n\nDefinition\x18\x06 \x01(\t\x12\x13\n\x0bMainPlayUrl\x18\x07 \x01(\t\x12\x15\n\rBackupPlayUrl\x18\x08 \x01(\t\x12\x0f\n\x07\x42itrate\x18\t \x01(\x05\x12\r\n\x05Width\x18\n \x01(\x05\x12\x0e\n\x06Height\x18\x0b \x01(\x05\x12\x0c\n\x04Size\x18\x0c \x01(\x01\x12\x11\n\tCheckInfo\x18\r \x01(\t\x12\x12\n\nIndexRange\x18\x0e \x01(\t\x12\x11\n\tInitRange\x18\x0f \x01(\t\x12\x10\n\x08PlayAuth\x18\x10 \x01(\t\x12\x12\n\nPlayAuthId\x18\x11 \x01(\t\x12\x10\n\x08LogoType\x18\x12 \x01(\t\x12\x0f\n\x07Quality\x18\x13 \x01(\t\x12\x19\n\x11\x42\x61rrageMaskOffset\x18\x14 \x01(\t\x12\x10\n\x08\x44uration\x18\x15 \x01(\x02\x12\x19\n\x11KeyFrameAlignment\x18\x16 \x01(\t\"\xa0\x01\n\x0cVodThumbInfo\x12\x12\n\nCaptureNum\x18\x01 \x01(\x05\x12\x11\n\tStoreUrls\x18\x02 \x03(\t\x12\x11\n\tCellWidth\x18\x03 \x01(\x05\x12\x12\n\nCellHeight\x18\x04 \x01(\x05\x12\x0f\n\x07ImgXLen\x18\x05 \x01(\x05\x12\x0f\n\x07ImgYLen\x18\x06 \x01(\x05\x12\x10\n\x08Interval\x18\x07 \x01(\x01\x12\x0e\n\x06\x46ormat\x18\x08 \x01(\t\"\x80\x02\n\x0fVodSubtitleInfo\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06\x46ileId\x18\x02 \x01(\t\x12\x10\n\x08Language\x18\x03 \x01(\t\x12\x12\n\nLanguageId\x18\x04 \x01(\x05\x12\x0e\n\x06\x46ormat\x18\x05 \x01(\t\x12\x12\n\nSubtitleId\x18\x06 \x01(\t\x12\r\n\x05Title\x18\x07 \x01(\t\x12\x0b\n\x03Tag\x18\x08 \x01(\t\x12\x0e\n\x06Status\x18\t \x01(\t\x12\x0e\n\x06Source\x18\n \x01(\t\x12\x10\n\x08StoreUri\x18\x0b \x01(\t\x12\x13\n\x0bSubtitleUrl\x18\x0c \x01(\t\x12\x12\n\nCreateTime\x18\r \x01(\t\x12\x0f\n\x07Version\x18\x0e \x01(\t\"A\n\x13VodCommonConfigInfo\x12\x0e\n\x06Module\x18\x01 \x01(\t\x12\x0b\n\x03Key\x18\x02 \x01(\t\x12\r\n\x05Value\x18\x03 \x01(\t\"\x8e\x04\n\x10VodPlayInfoModel\x12H\n\x07Version\x18\n \x01(\x0e\x32\x37.Volcengine.Vod.Models.Business.VodPlayInfoModelVersion\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x11\n\tPosterUrl\x18\x03 \x01(\t\x12\x10\n\x08\x44uration\x18\x04 \x01(\x02\x12\x10\n\x08\x46ileType\x18\x05 \x01(\t\x12\x16\n\x0e\x45nableAdaptive\x18\x06 \x01(\x08\x12\x12\n\nTotalCount\x18\x07 \x01(\x05\x12\x45\n\x0c\x41\x64\x61ptiveInfo\x18\x08 \x01(\x0b\x32/.Volcengine.Vod.Models.Business.VodAdaptiveInfo\x12\x41\n\x0cPlayInfoList\x18\t \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12\x43\n\rThumbInfoList\x18\x0b \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodThumbInfo\x12\x16\n\x0e\x42\x61rrageMaskUrl\x18\x0c \x01(\t\x12I\n\x10SubtitleInfoList\x18\r \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo\",\n\x08VodPoint\x12\x11\n\tTimestamp\x18\x01 \x01(\x01\x12\r\n\x05Value\x18\x02 \x01(\x01\"\x96\x01\n\x14VodAllPlayInfoResult\x12T\n\x17VodAllPlayInfoModelList\x18\x01 \x03(\x0b\x32\x33.Volcengine.Vod.Models.Business.VodAllPlayInfoModel\x12\x12\n\nTotalCount\x18\x02 \x01(\x05\x12\x14\n\x0cNotFoundVids\x18\x03 \x03(\t\"\xf6\x03\n\x13VodAllPlayInfoModel\x12\x0b\n\x03Vid\x18\x01 \x01(\t\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x11\n\tPosterUrl\x18\x03 \x01(\t\x12\x12\n\nTotalCount\x18\x04 \x01(\x05\x12\x16\n\x0e\x45nableAdaptive\x18\x05 \x01(\x08\x12I\n\x14VodTranscodePlayInfo\x18\x06 \x03(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12\x46\n\x11VodSourcePlayInfo\x18\x07 \x01(\x0b\x32+.Volcengine.Vod.Models.Business.VodPlayInfo\x12H\n\x07Version\x18\x08 \x01(\x0e\x32\x37.Volcengine.Vod.Models.Business.VodPlayInfoModelVersion\x12\x43\n\rThumbInfoList\x18\t \x03(\x0b\x32,.Volcengine.Vod.Models.Business.VodThumbInfo\x12\x16\n\x0e\x42\x61rrageMaskUrl\x18\n \x01(\t\x12I\n\x10SubtitleInfoList\x18\x0b \x03(\x0b\x32/.Volcengine.Vod.Models.Business.VodSubtitleInfo*\xd6\x01\n\x17VodPlayInfoModelVersion\x12$\n UndefinedVodPlayInfoModelVersion\x10\x00\x12%\n!InternalV1VodPlayInfoModelVersion\x10\x01\x12%\n!InternalV2VodPlayInfoModelVersion\x10\x02\x12%\n!InternalV3VodPlayInfoModelVersion\x10\x03\x12 \n\x1cToBV1VodPlayInfoModelVersion\x10\x04\x42\xcd\x01\n)com.volcengine.service.vod.model.businessB\tVodCommonP\x01ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02 Volc\\Service\\Vod\\Models\\Business\xe2\x02#Volc\\Service\\Vod\\Models\\GPBMetadatab\x06proto3')

_VODPLAYINFOMODELVERSION = DESCRIPTOR.enum_types_by_name['VodPlayInfoModelVersion']
VodPlayInfoModelVersion = enum_type_wrapper.EnumTypeWrapper(_VODPLAYINFOMODELVERSION)
UndefinedVodPlayInfoModelVersion = 0
InternalV1VodPlayInfoModelVersion = 1
InternalV2VodPlayInfoModelVersion = 2
InternalV3VodPlayInfoModelVersion = 3
ToBV1VodPlayInfoModelVersion = 4


_VODSOURCEINFO = DESCRIPTOR.message_types_by_name['VodSourceInfo']
_VODAUDIOSTREAMMETA = DESCRIPTOR.message_types_by_name['VodAudioStreamMeta']
_VODVIDEOSTREAMMETA = DESCRIPTOR.message_types_by_name['VodVideoStreamMeta']
_VODTRANSCODEINFO = DESCRIPTOR.message_types_by_name['VodTranscodeInfo']
_VODADAPTIVEINFO = DESCRIPTOR.message_types_by_name['VodAdaptiveInfo']
_VODPLAYINFO = DESCRIPTOR.message_types_by_name['VodPlayInfo']
_VODTHUMBINFO = DESCRIPTOR.message_types_by_name['VodThumbInfo']
_VODSUBTITLEINFO = DESCRIPTOR.message_types_by_name['VodSubtitleInfo']
_VODCOMMONCONFIGINFO = DESCRIPTOR.message_types_by_name['VodCommonConfigInfo']
_VODPLAYINFOMODEL = DESCRIPTOR.message_types_by_name['VodPlayInfoModel']
_VODPOINT = DESCRIPTOR.message_types_by_name['VodPoint']
_VODALLPLAYINFORESULT = DESCRIPTOR.message_types_by_name['VodAllPlayInfoResult']
_VODALLPLAYINFOMODEL = DESCRIPTOR.message_types_by_name['VodAllPlayInfoModel']
VodSourceInfo = _reflection.GeneratedProtocolMessageType('VodSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSOURCEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSourceInfo)
  })
_sym_db.RegisterMessage(VodSourceInfo)

VodAudioStreamMeta = _reflection.GeneratedProtocolMessageType('VodAudioStreamMeta', (_message.Message,), {
  'DESCRIPTOR' : _VODAUDIOSTREAMMETA,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAudioStreamMeta)
  })
_sym_db.RegisterMessage(VodAudioStreamMeta)

VodVideoStreamMeta = _reflection.GeneratedProtocolMessageType('VodVideoStreamMeta', (_message.Message,), {
  'DESCRIPTOR' : _VODVIDEOSTREAMMETA,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodVideoStreamMeta)
  })
_sym_db.RegisterMessage(VodVideoStreamMeta)

VodTranscodeInfo = _reflection.GeneratedProtocolMessageType('VodTranscodeInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODTRANSCODEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodTranscodeInfo)
  })
_sym_db.RegisterMessage(VodTranscodeInfo)

VodAdaptiveInfo = _reflection.GeneratedProtocolMessageType('VodAdaptiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODADAPTIVEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAdaptiveInfo)
  })
_sym_db.RegisterMessage(VodAdaptiveInfo)

VodPlayInfo = _reflection.GeneratedProtocolMessageType('VodPlayInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODPLAYINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPlayInfo)
  })
_sym_db.RegisterMessage(VodPlayInfo)

VodThumbInfo = _reflection.GeneratedProtocolMessageType('VodThumbInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODTHUMBINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodThumbInfo)
  })
_sym_db.RegisterMessage(VodThumbInfo)

VodSubtitleInfo = _reflection.GeneratedProtocolMessageType('VodSubtitleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODSUBTITLEINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodSubtitleInfo)
  })
_sym_db.RegisterMessage(VodSubtitleInfo)

VodCommonConfigInfo = _reflection.GeneratedProtocolMessageType('VodCommonConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _VODCOMMONCONFIGINFO,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodCommonConfigInfo)
  })
_sym_db.RegisterMessage(VodCommonConfigInfo)

VodPlayInfoModel = _reflection.GeneratedProtocolMessageType('VodPlayInfoModel', (_message.Message,), {
  'DESCRIPTOR' : _VODPLAYINFOMODEL,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPlayInfoModel)
  })
_sym_db.RegisterMessage(VodPlayInfoModel)

VodPoint = _reflection.GeneratedProtocolMessageType('VodPoint', (_message.Message,), {
  'DESCRIPTOR' : _VODPOINT,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodPoint)
  })
_sym_db.RegisterMessage(VodPoint)

VodAllPlayInfoResult = _reflection.GeneratedProtocolMessageType('VodAllPlayInfoResult', (_message.Message,), {
  'DESCRIPTOR' : _VODALLPLAYINFORESULT,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAllPlayInfoResult)
  })
_sym_db.RegisterMessage(VodAllPlayInfoResult)

VodAllPlayInfoModel = _reflection.GeneratedProtocolMessageType('VodAllPlayInfoModel', (_message.Message,), {
  'DESCRIPTOR' : _VODALLPLAYINFOMODEL,
  '__module__' : 'vod.business.vod_common_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Vod.Models.Business.VodAllPlayInfoModel)
  })
_sym_db.RegisterMessage(VodAllPlayInfoModel)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.volcengine.service.vod.model.businessB\tVodCommonP\001ZAgithub.com/volcengine/volc-sdk-golang/service/vod/models/business\240\001\001\330\001\001\302\002\000\312\002 Volc\\Service\\Vod\\Models\\Business\342\002#Volc\\Service\\Vod\\Models\\GPBMetadata'
  _VODPLAYINFOMODELVERSION._serialized_start=3149
  _VODPLAYINFOMODELVERSION._serialized_end=3363
  _VODSOURCEINFO._serialized_start=66
  _VODSOURCEINFO._serialized_end=327
  _VODAUDIOSTREAMMETA._serialized_start=329
  _VODAUDIOSTREAMMETA._serialized_end=436
  _VODVIDEOSTREAMMETA._serialized_start=439
  _VODVIDEOSTREAMMETA._serialized_end=573
  _VODTRANSCODEINFO._serialized_start=576
  _VODTRANSCODEINFO._serialized_end=916
  _VODADAPTIVEINFO._serialized_start=918
  _VODADAPTIVEINFO._serialized_end=1001
  _VODPLAYINFO._serialized_start=1004
  _VODPLAYINFO._serialized_end=1424
  _VODTHUMBINFO._serialized_start=1427
  _VODTHUMBINFO._serialized_end=1587
  _VODSUBTITLEINFO._serialized_start=1590
  _VODSUBTITLEINFO._serialized_end=1846
  _VODCOMMONCONFIGINFO._serialized_start=1848
  _VODCOMMONCONFIGINFO._serialized_end=1913
  _VODPLAYINFOMODEL._serialized_start=1916
  _VODPLAYINFOMODEL._serialized_end=2442
  _VODPOINT._serialized_start=2444
  _VODPOINT._serialized_end=2488
  _VODALLPLAYINFORESULT._serialized_start=2491
  _VODALLPLAYINFORESULT._serialized_end=2641
  _VODALLPLAYINFOMODEL._serialized_start=2644
  _VODALLPLAYINFOMODEL._serialized_end=3146
# @@protoc_insertion_point(module_scope)



import json
import threading
import redo

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from requests import exceptions


class ContentSecurityService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(ContentSecurityService, "_instance"):
            with ContentSecurityService._instance_lock:
                if not hasattr(ContentSecurityService, "_instance"):
                    ContentSecurityService._instance = object.__new__(cls)
        return ContentSecurityService._instance

    def __init__(self):
        self.service_info = ContentSecurityService.get_service_info()
        self.api_info = ContentSecurityService.get_api_info()
        super(ContentSecurityService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'BusinessSecurity', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"AsyncVideoRisk": ApiInfo("POST", "/", {"Action": "AsyncVideoRisk", "Version": "2021-11-29"}, {}, {}),
                    "VideoResult": ApiInfo("GET", "/", {"Action": "VideoResult", "Version": "2021-11-29"}, {}, {}),
                    "ImageContentRisk": ApiInfo("POST", "/", {"Action": "ImageContentRisk", "Version": "2021-11-29"}, {}, {}),
                    "AsyncImageRisk": ApiInfo("POST", "/", {"Action": "AsyncImageRisk", "Version": "2021-11-29"}, {}, {}),
                    "ImageResult": ApiInfo("GET", "/", {"Action": "GetImageResult", "Version": "2021-11-29"}, {}, {}),
                    "TextRisk": ApiInfo("POST", "/", {"Action": "TextRisk", "Version": "2022-01-26"}, {}, {}),
                    "CreateCustomContents": ApiInfo("POST", "/", {"Action": "CreateCustomContents", "Version": "2022-01-22"}, {}, {}),
                    "UploadCustomContents": ApiInfo("POST", "/", {"Action": "UploadCustomContents", "Version": "2022-02-07"}, {}, {}),
                    "EnableCustomContents": ApiInfo("PUT", "/", {"Action": "EnableCustomContents", "Version": "2022-04-28"}, {}, {}),
                    "DisableCustomContents": ApiInfo("PUT", "/", {"Action": "DisableCustomContents", "Version": "2022-04-28"}, {}, {}),
                    "DeleteCustomContents": ApiInfo("PUT", "/", {"Action": "DeleteCustomContents", "Version": "2022-04-28"}, {}, {}),
                    "AsyncAudioRisk": ApiInfo("POST", "/", {"Action": "AsyncAudioRisk", "Version": "2022-04-01"}, {}, {}),
                    "GetAudioResult": ApiInfo("GET", "/", {"Action": "GetAudioResult", "Version": "2022-04-01"}, {}, {}),
                    "AsyncLiveVideoRisk": ApiInfo("POST", "/", {"Action": "AsyncLiveVideoRisk", "Version": "2022-04-25"}, {}, {}),
                    "GetVideoLiveResult": ApiInfo("GET", "/", {"Action": "GetVideoLiveResult", "Version": "2022-04-25"}, {}, {}),
                    "AsyncLiveAudioRisk": ApiInfo("POST", "/", {"Action": "AsyncLiveAudioRisk", "Version": "2022-04-25"}, {}, {}),
                    "GetAudioLiveResult": ApiInfo("GET", "/", {"Action": "GetAudioLiveResult", "Version": "2022-04-25"}, {}, {})
                    }

        return api_info

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def async_video_risk(self, params, body):
        res = self.json("AsyncVideoRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def video_result(self, params, body):
        res = self.get("VideoResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def image_content_risk(self, params, body):
        res = self.json("ImageContentRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def async_image_risk(self, params, body):
        res = self.json("AsyncImageRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def image_result(self, params, body):
        res = self.get("ImageResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def text_risk(self, params, body):
        res = self.json("TextRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def create_custom_contents(self, params, body):
        res = self.json("CreateCustomContents", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def upload_custom_contents(self, params, body):
        res = self.json("UploadCustomContents", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def enable_custom_contents(self, params, body):
        res = self.json("EnableCustomContents", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def disable_custom_contents(self, params, body):
        res = self.json("DisableCustomContents", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def delete_custom_contents(self, params, body):
        res = self.json("DeleteCustomContents", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def async_live_video_risk(self, params, body):
        res = self.json("AsyncLiveVideoRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def async_audio_risk(self, params, body):
        res = self.json("AsyncAudioRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def audio_result(self, params, body):
        res = self.get("GetAudioResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def async_live_audio_risk(self, params, body):
        res = self.json("AsyncLiveAudioRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def live_audio_result(self, params, body):
        res = self.get("GetVideoLiveResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    def live_video_result(self, params, body):
        res = self.get("GetAudioLiveResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



import json
import threading


from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
import redo
from requests import exceptions
class AdBlockService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(AdBlockService, "_instance"):
            with AdBlockService._instance_lock:
                if not hasattr(AdBlockService, "_instance"):
                    AdBlockService._instance = object.__new__(cls)
        return AdBlockService._instance

    def __init__(self):
        self.service_info = AdBlockService.get_service_info()
        self.api_info = AdBlockService.get_api_info()
        super(AdBlockService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'AdBlocker', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"AdBlock": ApiInfo("POST", "/", {"Action": "AdBlock", "Version": "2021-01-06"}, {}, {})}
        return api_info

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def ad_block(self, params, body):
        res = self.json("AdBlock", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json






# Code generated by protoc-gen-volcengine-sdk
# source: ImpService
# DO NOT EDIT!
# coding:utf-8
from __future__ import print_function
from google.protobuf.json_format import *
from volcengine.imp.ImpServiceConfig import ImpServiceConfig
from volcengine.imp.models.response.response_imp_pb2 import *

MinChunkSize = 1024 * 1024 * 20
LargeFileSize = 1024 * 1024 * 1024


#
# Generated from protobuf service <code>ImpService</code>
#
class ImpService(ImpServiceConfig):
    #
    # SubmitJob.
    #
    # @param request ImpSubmitJobRequest
    # @return ImpSubmitJobResponse
    # @raise Exception
    def submit_job(self, request):
        try:
            if sys.version_info[0] == 3:
                jsonData = MessageToJson(request, False, True)
                params = json.loads(jsonData)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            else:
                params = MessageToDict(request, False, True)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str, unicode)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            res = self.get("SubmitJob", params)
        except Exception as Argument:
            try:
                resp = Parse(Argument.__str__(), ImpSubmitJobResponse(), True)
            except Exception:
                raise Argument
            else:
                raise Exception(resp.ResponseMetadata.Error.Code)
        else:
            return Parse(res, ImpSubmitJobResponse(), True)

    #
    # KillJob.
    #
    # @param request ImpKillJobRequest
    # @return ImpKillJobResponse
    # @raise Exception
    def kill_job(self, request):
        try:
            if sys.version_info[0] == 3:
                jsonData = MessageToJson(request, False, True)
                params = json.loads(jsonData)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            else:
                params = MessageToDict(request, False, True)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str, unicode)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            res = self.get("KillJob", params)
        except Exception as Argument:
            try:
                resp = Parse(Argument.__str__(), ImpKillJobResponse(), True)
            except Exception:
                raise Argument
            else:
                raise Exception(resp.ResponseMetadata.Error.Code)
        else:
            return Parse(res, ImpKillJobResponse(), True)

    #
    # RetrieveJob.
    #
    # @param request ImpRetrieveJobRequest
    # @return ImpRetrieveJobResponse
    # @raise Exception
    def retrieve_job(self, request):
        try:
            if sys.version_info[0] == 3:
                jsonData = MessageToJson(request, False, True)
                params = json.loads(jsonData)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            else:
                params = MessageToDict(request, False, True)
                for k, v in params.items():
                    if isinstance(v, (int, float, bool, str, unicode)) is True:
                        continue
                    else:
                        params[k] = json.dumps(v)
            res = self.get("RetrieveJob", params)
        except Exception as Argument:
            try:
                resp = Parse(Argument.__str__(), ImpRetrieveJobResponse(), True)
            except Exception:
                raise Argument
            else:
                raise Exception(resp.ResponseMetadata.Error.Code)
        else:
            return Parse(res, ImpRetrieveJobResponse(), True)




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: imp/request/request_imp.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from volcengine.imp.models.business import imp_common_pb2 as imp_dot_business_dot_imp__common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='imp/request/request_imp.proto',
  package='Volcengine.Imp.Models.Request',
  syntax='proto3',
  serialized_options=b'\n(com.volcengine.service.imp.model.requestB\nImpRequestP\001Z@github.com/volcengine/volc-sdk-golang/service/imp/models/request\240\001\001\330\001\001\312\002\037Volc\\Service\\Imp\\Models\\Request\342\002#Volc\\Service\\Imp\\Models\\GPBMetadata',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dimp/request/request_imp.proto\x12\x1dVolcengine.Imp.Models.Request\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dimp/business/imp_common.proto\"}\n\x13ImpSubmitJobRequest\x12<\n\tInputPath\x18\x01 \x01(\x0b\x32).Volcengine.Imp.Models.Business.InputPath\x12\x12\n\nTemplateId\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llbackArgs\x18\x03 \x01(\t\"\"\n\x11ImpKillJobRequest\x12\r\n\x05JobId\x18\x01 \x01(\t\"\'\n\x15ImpRetrieveJobRequest\x12\x0e\n\x06JobIds\x18\x01 \x03(\tB\xc8\x01\n(com.volcengine.service.imp.model.requestB\nImpRequestP\x01Z@github.com/volcengine/volc-sdk-golang/service/imp/models/request\xa0\x01\x01\xd8\x01\x01\xca\x02\x1fVolc\\Service\\Imp\\Models\\Request\xe2\x02#Volc\\Service\\Imp\\Models\\GPBMetadatab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,imp_dot_business_dot_imp__common__pb2.DESCRIPTOR,])




_IMPSUBMITJOBREQUEST = _descriptor.Descriptor(
  name='ImpSubmitJobRequest',
  full_name='Volcengine.Imp.Models.Request.ImpSubmitJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='InputPath', full_name='Volcengine.Imp.Models.Request.ImpSubmitJobRequest.InputPath', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TemplateId', full_name='Volcengine.Imp.Models.Request.ImpSubmitJobRequest.TemplateId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CallbackArgs', full_name='Volcengine.Imp.Models.Request.ImpSubmitJobRequest.CallbackArgs', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=252,
)


_IMPKILLJOBREQUEST = _descriptor.Descriptor(
  name='ImpKillJobRequest',
  full_name='Volcengine.Imp.Models.Request.ImpKillJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobId', full_name='Volcengine.Imp.Models.Request.ImpKillJobRequest.JobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=288,
)


_IMPRETRIEVEJOBREQUEST = _descriptor.Descriptor(
  name='ImpRetrieveJobRequest',
  full_name='Volcengine.Imp.Models.Request.ImpRetrieveJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='JobIds', full_name='Volcengine.Imp.Models.Request.ImpRetrieveJobRequest.JobIds', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=329,
)

_IMPSUBMITJOBREQUEST.fields_by_name['InputPath'].message_type = imp_dot_business_dot_imp__common__pb2._INPUTPATH
DESCRIPTOR.message_types_by_name['ImpSubmitJobRequest'] = _IMPSUBMITJOBREQUEST
DESCRIPTOR.message_types_by_name['ImpKillJobRequest'] = _IMPKILLJOBREQUEST
DESCRIPTOR.message_types_by_name['ImpRetrieveJobRequest'] = _IMPRETRIEVEJOBREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImpSubmitJobRequest = _reflection.GeneratedProtocolMessageType('ImpSubmitJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPSUBMITJOBREQUEST,
  '__module__' : 'imp.request.request_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Request.ImpSubmitJobRequest)
  })
_sym_db.RegisterMessage(ImpSubmitJobRequest)

ImpKillJobRequest = _reflection.GeneratedProtocolMessageType('ImpKillJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPKILLJOBREQUEST,
  '__module__' : 'imp.request.request_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Request.ImpKillJobRequest)
  })
_sym_db.RegisterMessage(ImpKillJobRequest)

ImpRetrieveJobRequest = _reflection.GeneratedProtocolMessageType('ImpRetrieveJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPRETRIEVEJOBREQUEST,
  '__module__' : 'imp.request.request_imp_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Imp.Models.Request.ImpRetrieveJobRequest)
  })
_sym_db.RegisterMessage(ImpRetrieveJobRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    params = {
        "SingleOpenId": "9b39e17fb12444c78f20d6551469a6e0"
    }

    print(notify_service.single_info(params))


import json
import threading
import redo

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from requests import exceptions


class RiskDetectService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(RiskDetectService, "_instance"):
            with RiskDetectService._instance_lock:
                if not hasattr(RiskDetectService, "_instance"):
                    RiskDetectService._instance = object.__new__(cls)
        return RiskDetectService._instance

    def __init__(self):
        self.service_info = RiskDetectService.get_service_info()
        self.api_info = RiskDetectService.get_api_info()
        super(RiskDetectService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'BusinessSecurity', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"RiskDetection": ApiInfo("POST", "/", {"Action": "RiskDetection", "Version": "2021-02-02"}, {}, {}),
                    "AsyncRiskDetection": ApiInfo("POST", "/", {"Action": "AsyncRiskDetection", "Version": "2021-02-25"}, {}, {}),
                    "RiskResult": ApiInfo("GET", "/", {"Action": "RiskResult", "Version": "2021-03-10"}, {}, {}),
                    "AccountRisk": ApiInfo("POST", "/", {"Action": "AccountRisk", "Version": "2020-12-25"}, {}, {}),
                    "MobileStatus": ApiInfo("POST", "/", {"Action": "MobileStatus", "Version": "2020-12-25"}, {}, {}),
                    "ElementVerify": ApiInfo("POST", "/", {"Action": "ElementVerify", "Version": "2021-11-23"}, {}, {}),
                    "MobileStatusV2": ApiInfo("POST", "/", {"Action": "MobileStatus", "Version": "2022-04-13"}, {}, {}),
                    "ElementVerifyV2": ApiInfo("POST", "/", {"Action": "ElementVerify", "Version": "2022-04-13"}, {}, {})}

        return api_info

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def risk_detect(self, params, body):
        res = self.json("RiskDetection", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def async_risk_detect(self, params, body):
        res = self.json("AsyncRiskDetection", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2, retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def risk_result(self, params, body):
        res = self.get("RiskResult", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def account_risk(self, params, body):
        res = self.json("AccountRisk", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def mobile_status(self, params, body):
        res = self.json("MobileStatus", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def element_verify(self, params, body):
        res = self.json("ElementVerify", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def mobile_status_v2(self, params, body):
        res = self.json("MobileStatusV2", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def element_verify_v2(self, params, body):
        res = self.json("ElementVerifyV2", params, json.dumps(body))
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json


# coding:utf-8
from __future__ import print_function
from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    imagex_service.set_ak('ak')
    imagex_service.set_sk('sk')

    params = dict()
    params['ServiceId'] = 'imagex service id'
    params['StoreUri'] = 'image uri'

    resp = imagex_service.imagex_get('GetImageUploadFile', params)
    print(resp)



#  -*- coding: utf-8 -*-
from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    resp = svc.describe_content_quota()
    print(resp)



# coding : utf-8
import datetime
import sys

import pytz

try:
    from urllib import urlencode
except:
    from urllib.parse import urlencode

from volcengine.auth.MetaData import MetaData
from volcengine.util.Util import Util
from volcengine.base.Request import Request
from volcengine.auth.SignResult import SignResult

class SignerV4(object):
    @staticmethod
    def sign(request, credentials):
        if request.path == '':
            request.path = '/'
        if request.method != 'GET' and not ('Content-Type' in request.headers):
            request.headers['Content-Type'] = 'application/x-www-form-urlencoded; charset=utf-8'

        format_date = SignerV4.get_current_format_date()
        request.headers['X-Date'] = format_date

        md = MetaData()
        md.set_algorithm('HMAC-SHA256')
        md.set_service(credentials.service)
        md.set_region(credentials.region)
        md.set_date(format_date[:8])

        hashed_canon_req = SignerV4.hashed_canonical_request_v4(request, md)
        md.set_credential_scope('/'.join([md.date, md.region, md.service, 'request']))

        signing_str = '\n'.join([md.algorithm, format_date, md.credential_scope, hashed_canon_req])
        signing_key = SignerV4.get_signing_secret_key_v4(credentials.sk, md.date, md.region, md.service)
        sign = Util.to_hex(Util.hmac_sha256(signing_key, signing_str))
        request.headers['Authorization'] = SignerV4.build_auth_header_v4(sign, md, credentials)
        return

    @staticmethod
    def sign_url(request, credentials):
        format_date = SignerV4.get_current_format_date()
        date = format_date[:8]

        md = MetaData()
        md.set_date(date)
        md.set_service(credentials.service)
        md.set_region(credentials.region)
        md.set_signed_headers('')
        md.set_algorithm('HMAC-SHA256')
        md.set_credential_scope('/'.join([md.date, md.region, md.service, 'request']))

        query = request.query
        query['X-Date'] = format_date
        query['X-NotSignBody'] = ''
        query['X-Credential'] = credentials.ak + '/' + md.credential_scope
        query['X-Algorithm'] = md.algorithm
        query['X-SignedHeaders'] = md.signed_headers
        query['X-SignedQueries'] = ''
        query['X-SignedQueries'] = ';'.join(sorted(query.keys()))

        hashed_canon_req = SignerV4.hashed_simple_canonical_request_v4(request, md)
        signing_str = '\n'.join([md.algorithm, format_date, md.credential_scope, hashed_canon_req])
        signing_key = SignerV4.get_signing_secret_key_v4(credentials.sk, md.date, md.region, md.service)
        sign = SignerV4.signature_v4(signing_key, signing_str)

        query['X-Signature'] = sign
        return urlencode(query)

    @staticmethod
    def sign_only(param, credentials):
        request = Request()
        request.host = param.host
        request.method = param.method
        request.path = param.path
        request.body = param.body
        request.query = param.query
        request.headers = param.header_list

        format_date = param.date.strftime("%Y%m%dT%H%M%SZ")
        date = format_date[:8]
        request.headers['X-Date'] = format_date
        md = MetaData()
        md.set_algorithm('HMAC-SHA256')
        md.set_service(credentials.service)
        md.set_region(credentials.region)
        md.set_date(date)
        md.set_credential_scope('/'.join([md.date, md.region, md.service, 'request']))

        if param.is_sign_url:
            md.set_signed_headers('')
            md.set_credential_scope('/'.join([md.date, md.region, md.service, 'request']))
            query = request.query
            query['X-Date'] = format_date
            query['X-NotSignBody'] = ''
            query['X-Credential'] = credentials.ak + '/' + md.credential_scope
            query['X-Algorithm'] = md.algorithm
            query['X-SignedHeaders'] = md.signed_headers
            query['X-SignedQueries'] = ''
            query['X-SignedQueries'] = ';'.join(sorted(query.keys()))
            hashed_canon_req = SignerV4.hashed_simple_canonical_request_v4(request, md)
        else:
            hashed_canon_req = SignerV4.hashed_canonical_request_v4(request, md)

        signing_str = '\n'.join([md.algorithm, format_date, md.credential_scope, hashed_canon_req])
        signing_key = SignerV4.get_signing_secret_key_v4(credentials.sk, md.date, md.region, md.service)
        sign = SignerV4.signature_v4(signing_key, signing_str)

        result = SignResult()
        result.xdate = format_date
        result.xAlgorithm = md.algorithm
        if param.is_sign_url:
            result.xSignedQueries = request.query['X-SignedQueries']
        result.xSignedHeaders = md.signed_headers
        result.xCredential = credentials.ak + '/' + md.credential_scope
        result.xSignature = sign
        result.authorization = result.xAlgorithm + " Credential=" + result.xCredential + ", SignedHeaders=" + md.signed_headers + ", Signature=" + result.xSignature

        return result

    @staticmethod
    def hashed_simple_canonical_request_v4(request, meta):
        body = bytes()
        # if sys.version_info[0] == 3:
        #     body_hash = Util.sha256(body.decode('utf-8'))
        # else:
        body_hash = Util.sha256(body)

        if request.path == '':
            request.path = '/'

        canoncial_request = '\n'.join(
            [request.method, Util.norm_uri(request.path), Util.norm_query(request.query), '\n',
             meta.signed_headers, body_hash])
        # if sys.version_info[0] == 3:
        #     return Util.sha256(canoncial_request.decode('utf-8'))
        # else:
        return Util.sha256(canoncial_request)

    @staticmethod
    def hashed_canonical_request_v4(request, meta):
        # if sys.version_info[0] == 3:
        #     body_hash = Util.sha256(request.body.decode('utf-8'))
        # else:
        body_hash = Util.sha256(request.body)
        request.headers['X-Content-Sha256'] = body_hash

        signed_headers = dict()
        for key in request.headers:
            if key in ['Content-Type', 'Content-Md5', 'Host'] or key.startswith('X-'):
                signed_headers[key.lower()] = request.headers[key]

        if 'host' in signed_headers:
            v = signed_headers['host']
            if v.find(':') != -1:
                split = v.split(':')
                port = split[1]
                if str(port) == '80' or str(port) == '443':
                    signed_headers['host'] = split[0]

        signed_str = ''
        for key in sorted(signed_headers.keys()):
            signed_str += key + ':' + signed_headers[key] + '\n'

        meta.set_signed_headers(';'.join(sorted(signed_headers.keys())))

        canoncial_request = '\n'.join(
            [request.method, Util.norm_uri(request.path), Util.norm_query(request.query), signed_str,
             meta.signed_headers, body_hash])

        return Util.sha256(canoncial_request)

    @staticmethod
    def signature_v4(signing_key, signing_str):
        return Util.to_hex(Util.hmac_sha256(signing_key, signing_str))

    @staticmethod
    def get_signing_secret_key_v4(sk, date, region, service):
        if sys.version_info[0] == 3:
            kdate = Util.hmac_sha256(bytes(sk, encoding='utf-8'), date)
        else:
            kdate = Util.hmac_sha256(sk.encode('utf-8'), date)
        kregion = Util.hmac_sha256(kdate, region)
        kservice = Util.hmac_sha256(kregion, service)
        return Util.hmac_sha256(kservice, 'request')

    @staticmethod
    def build_auth_header_v4(signature, meta, credentials):
        credential = credentials.ak + '/' + meta.credential_scope
        return meta.algorithm + ' Credential=' + credential + ', SignedHeaders=' + meta.signed_headers + ', Signature=' + signature

    @staticmethod
    def get_current_format_date():
        return datetime.datetime.now(tz=pytz.timezone('UTC')).strftime("%Y%m%dT%H%M%SZ")



#  -*- coding: utf-8 -*-
import datetime

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)
    now = int(datetime.datetime.now().strftime("%s"))
    body = {
        'Metric': 'status_5xx',
        'Item': 'domain'
    }
    print(body)

    resp = svc.describe_edge_top_status_code(body)
    print(resp)



# coding:utf-8
from __future__ import print_function
from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    imagex_service.set_ak('your ak')
    imagex_service.set_sk('your sk')

    params = dict()
    params['ServiceId'] = 'xx'
    params['Class'] = 'class'
    params['Refine'] = True
    params['StoreUri'] = 'store uri'
    params['OutFormat'] = 'out format'
    params['TransBg'] = True
    params['Color'] = {
        'Color': "color",
        'Size': 0
    }

    resp = imagex_service.get_image_segment(params)
    print(resp)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base/base.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62\x61se/base.proto\x12\x1bVolcengine.Base.Models.Base\x1a google/protobuf/descriptor.proto\"\xa2\x01\n\x10ResponseMetadata\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\x0e\n\x06\x41\x63tion\x18\x02 \x01(\t\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x0f\n\x07Service\x18\x04 \x01(\t\x12\x0e\n\x06Region\x18\x05 \x01(\t\x12\x39\n\x05\x45rror\x18\x06 \x01(\x0b\x32*.Volcengine.Base.Models.Base.ResponseError\".\n\rResponseError\x12\x0c\n\x04\x43ode\x18\x01 \x01(\t\x12\x0f\n\x07Message\x18\x02 \x01(\tB\xc0\x01\n&com.volcengine.service.base.model.baseB\x04\x42\x61seP\x01Z>github.com/volcengine/volc-sdk-golang/service/base/models/base\xa0\x01\x01\xd8\x01\x01\xc2\x02\x00\xca\x02\x1dVolc\\Service\\Base\\Models\\Base\xe2\x02$Volc\\Service\\Base\\Models\\GPBMetadatab\x06proto3')



_RESPONSEMETADATA = DESCRIPTOR.message_types_by_name['ResponseMetadata']
_RESPONSEERROR = DESCRIPTOR.message_types_by_name['ResponseError']
ResponseMetadata = _reflection.GeneratedProtocolMessageType('ResponseMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEMETADATA,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Base.Models.Base.ResponseMetadata)
  })
_sym_db.RegisterMessage(ResponseMetadata)

ResponseError = _reflection.GeneratedProtocolMessageType('ResponseError', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEERROR,
  '__module__' : 'base.base_pb2'
  # @@protoc_insertion_point(class_scope:Volcengine.Base.Models.Base.ResponseError)
  })
_sym_db.RegisterMessage(ResponseError)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.volcengine.service.base.model.baseB\004BaseP\001Z>github.com/volcengine/volc-sdk-golang/service/base/models/base\240\001\001\330\001\001\302\002\000\312\002\035Volc\\Service\\Base\\Models\\Base\342\002$Volc\\Service\\Base\\Models\\GPBMetadata'
  _RESPONSEMETADATA._serialized_start=83
  _RESPONSEMETADATA._serialized_end=245
  _RESPONSEERROR._serialized_start=247
  _RESPONSEERROR._serialized_end=293
# @@protoc_insertion_point(module_scope)



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    body = {
        'Name': "test",
        'LiveTime': 1628067360,
        'CoverImage': "",
        'IsReplayAutoOnlineEnable': 1,
        'IsWatermark': 0,
        'ProtectModeCode': "",
        'ViewUrlPath': "",
        'TemplateId': 0
    }

    resp = livesaasService.create_activity_api(body)
    # resp = await livesaasService.async_create_activity_api(body)
    print(resp)



#  -*- coding: utf-8 -*-
from __future__ import print_function

from volcengine.nlp.NLPService import NLPService

if __name__ == '__main__':
    nlp_service = NLPService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    nlp_service.set_ak('ak')
    nlp_service.set_sk('sk')

    params = dict()

    body = {
        "text": "我很生气"
    }

    resp = nlp_service.sentiment_analysis(body)
    print(resp)



# coding: utf-8

REGION_CN_NORTH1 = "cn-north-1"
REGION_US_EAST1 = "us-east-1"
REGION_AP_SINGAPORE1 = "ap-singapore-1"

INNER_REGION_CN_NORTH1 = "cn-north-1-inner"
INNER_REGION_US_EAST1 = "us-east-1-inner"
INNER_REGION_AP_SINGAPORE1 = "ap-singapore-1-inner"

HTTP = 'http'
HTTPS = 'https'

FILE_TYPE_VIDEO = 'video'
FILE_TYPE_MEDIA = 'media'
FILE_TYPE_IMAGE = 'image'
FILE_TYPE_OBJECT = 'object'

UPLOAD_FORMAT_MP4 = 'mp4'
UPLOAD_FORMAT_M3U8 = 'm3u8'

FORMAT_JPEG = 'jpeg'
FORMAT_PNG = 'png'
FORMAT_WEBP = 'webp'
FORMAT_AWEBP = 'awebp'
FORMAT_GIF = 'gif'
FORMAT_HEIC = 'heic'
FORMAT_ORIGINAL = 'image'

VOD_TPL_OBJ = 'tplv-vod-obj'
VOD_TPL_NOOP = 'tplv-vod-noop'
VOD_TPL_RESIZE = 'tplv-vod-rs'
VOD_TPL_CENTER_CROP = 'tplv-vod-cc'
VOD_TPL_SMART_CROP = 'tplv-vod-cs'
VOD_TPL_SIG = 'tplv-bd-sig'

LETTER_RUNES = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

RESOURCE_SPACE_FORMAT = "trn:vod:%s:*:space/%s"
RESOURCE_VIDEO_FORMAT = 'trn:vod::*:video_id/%s'
RESOURCE_STREAM_TYPE_FORMAT = 'trn:vod:::stream_type/%s'
RESOURCE_WATERMARK_FORMAT = 'trn:vod::*:watermark/%s'

ACTION_VOD_GET_PLAY_INFO = "vod:GetPlayInfo"

STAR = '*'

CATEGORY_VIDEO = "video"
CATEGORY_AUDIO = "audio"
CATEGORY_IMAGE = "image"
CATEGORY_DYNAMICIMG = "dynamic_img"
CATEGORY_SUBTITLE = "subtitle"
CATEGORY_FONT = "font"



# coding:utf-8


class MetaData(object):
    def __init__(self):
        self.algorithm = ''
        self.credential_scope = ''
        self.signed_headers = ''
        self.date = ''
        self.region = ''
        self.service = ''

    def set_date(self, date):
        self.date = date

    def set_service(self, service):
        self.service = service

    def set_region(self, region):
        self.region = region

    def set_algorithm(self, algorithm):
        self.algorithm = algorithm

    def set_credential_scope(self, credential_scope):
        self.credential_scope = credential_scope

    def set_signed_headers(self, signed_headers):
        self.signed_headers = signed_headers


# coding:utf-8
from __future__ import print_function

import json

from volcengine.vedit.VEditService import VEditService

if __name__ == '__main__':
    edit_service = VEditService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    # edit_service.set_ak('ak')
    # edit_service.set_sk('sk')

    body = {}
    body["EditParam"] = {
        "Upload": {
            "Uploader": "your uploader",
            "VideoName": "your video name"
        },
        "Output": {
            "Fps": 25,
            "Height": 720,
            "Quality": "medium",
            "Width": 1280
        },
        "Segments": [{
            "BackGround": "0xFFFFFFFF",
            "Duration": 3,
            "Elements": [],
            "Volume": 1
        }],
        "GlobalElements": []
    }
    body["Priority"] = 0
    body["CallbackArgs"] = "your callback args"
    body["CallbackUri"] = "your callback uri"

    body = json.dumps(body)
    resp = edit_service.submit_direct_edit_task_async(body)
    print(resp)

    print("****")

    body = {}
    body["ReqIds"] = ["your req id 1", "your req id 2"]

    body = json.dumps(body)
    resp = edit_service.get_direct_edit_result(body)
    print(resp)



# coding:utf-8
import threading

import redo

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service
from volcengine.const.Const import *
from volcengine.Policy import *
from requests import exceptions


NOTIFY_SERVICE_NAME = "volc_voice_notify"
NOTIFY_API_VERSION = "2021-01-01"

service_info_map = {
    REGION_CN_NORTH1: ServiceInfo(
        "cloud-vms.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', NOTIFY_SERVICE_NAME, REGION_CN_NORTH1),
        10, 10
    ),
}

notify_api_info = {
    "CreateTask":
        ApiInfo("POST", "/", {"Action": "CreateTask", "Version": NOTIFY_API_VERSION}, {}, {}),
    "BatchAppend":
        ApiInfo("POST", "/", {"Action": "BatchAppend", "Version": NOTIFY_API_VERSION}, {}, {}),
    "PauseTask":
        ApiInfo("POST", "/", {"Action": "PauseTask", "Version": NOTIFY_API_VERSION}, {}, {}),
    "ResumeTask":
        ApiInfo("POST", "/", {"Action": "ResumeTask", "Version": NOTIFY_API_VERSION}, {}, {}),
    "StopTask":
        ApiInfo("POST", "/", {"Action": "StopTask", "Version": NOTIFY_API_VERSION}, {}, {}),
    "UpdateTask":
        ApiInfo("POST", "/", {"Action": "UpdateTask", "Version": NOTIFY_API_VERSION}, {}, {}),
    "SingleBatchAppend":
        ApiInfo("POST", "/", {"Action": "SingleBatchAppend", "Version": NOTIFY_API_VERSION}, {}, {}),
    "SingleInfo":
        ApiInfo("GET", "/", {"Action": "SingleInfo", "Version": NOTIFY_API_VERSION}, {}, {}),
    "SingleCancel":
        ApiInfo("GET", "/", {"Action": "SingleCancel", "Version": NOTIFY_API_VERSION}, {}, {}),
    "FetchResource":
        ApiInfo("POST", "/", {"Action": "FetchResource", "Version": NOTIFY_API_VERSION}, {}, {}),
    "OpenCreateTts":
        ApiInfo("POST", "/", {"Action": "OpenCreateTts", "Version": NOTIFY_API_VERSION}, {}, {}),
    "OpenDeleteResource":
        ApiInfo("POST", "/", {"Action": "OpenDeleteResource", "Version": NOTIFY_API_VERSION}, {}, {}),
    "GetResourceUploadUrl":
        ApiInfo("POST", "/", {"Action": "GetResourceUploadUrl", "Version": NOTIFY_API_VERSION}, {}, {}),
    "CommitResourceUpload":
        ApiInfo("POST", "/", {"Action": "CommitResourceUpload", "Version": NOTIFY_API_VERSION}, {}, {}),
}


class NotifyService(Service):

    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(NotifyService, "_instance"):
            with NotifyService._instance_lock:
                if not hasattr(NotifyService, "_instance"):
                    NotifyService._instance = object.__new__(cls)
        return NotifyService._instance

    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = NotifyService.get_service_info(region)
        self.api_info = NotifyService.get_api_info()
        super(NotifyService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Notify service not support region %s' % region)
        return service_info

    @staticmethod
    def get_api_info():
        return notify_api_info

    def do_json_handler(self, api, body, params=dict()):
        try:
            res = self.json(api, params, json.dumps(body))
            return json.loads(res)
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    def do_query_handler(self, api, params):
        try:
            res = self.get(api, params)
            return json.loads(res)
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_task(self, body):
        try:
            res_json = self.do_json_handler("CreateTask", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def batch_append_task(self, body):
        try:
            res_json = self.do_json_handler("BatchAppend", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def update_task(self, body):
        try:
            res_json = self.do_json_handler("UpdateTask", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def pause_task(self, params):
        try:
            res_json = self.do_json_handler("PauseTask", dict(), params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def resume_task(self, params):
        try:
            res_json = self.do_json_handler("ResumeTask", dict(), params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def stop_task(self, params):
        try:
            res_json = self.do_json_handler("StopTask", dict(), params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def single_batch_append(self, body):
        try:
            res_json = self.do_json_handler("SingleBatchAppend", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def single_info(self, params):
        try:
            res_json = self.do_query_handler("SingleInfo", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def single_cancel(self, params):
        try:
            res_json = self.do_query_handler("SingleCancel", params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def fetch_resource(self, body):
        try:
            res_json = self.do_json_handler("FetchResource", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def create_tts(self, body):
        try:
            res_json = self.do_json_handler("OpenCreateTts", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def delete_resource(self, params):
        try:
            res_json = self.do_json_handler("OpenDeleteResource", dict(), params)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def get_resource_upload_url(self, body):
        try:
            res_json = self.do_json_handler("GetResourceUploadUrl", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))

    @redo.retriable(sleeptime=0.1, jitter=0.01, attempts=2,
                    retry_exceptions=(exceptions.ConnectionError, exceptions.ConnectTimeout))
    def commit_resource_upload(self, body):
        try:
            res_json = self.do_json_handler("CommitResourceUpload", body)
            return res_json
        except Exception as e:
            raise Exception(str(e))



# coding:utf-8
import json
import os
import queue
import threading
from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service
from volcengine.const.Const import *
from volcengine.util.Util import *
from volcengine.Policy import *

IMAGEX_SERVICE_NAME = "ImageX"
IMAGEX_API_VERSION = "2018-08-01"

ResourceServiceIdTRN = "trn:ImageX:*:*:ServiceId/%s"
ResourceStoreKeyTRN = "trn:ImageX:*:*:StoreKeys/%s"

UPLOAD_THREADS = 3

service_info_map = {
    REGION_CN_NORTH1: ServiceInfo(
        "imagex.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_CN_NORTH1),
        10, 10, "https"),
    REGION_AP_SINGAPORE1: ServiceInfo(
        "imagex-ap-singapore-1.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_AP_SINGAPORE1),
        10, 10, "https"),
    REGION_US_EAST1: ServiceInfo(
        "imagex-us-east-1.volcengineapi.com",
        {'Accept': 'application/json'},
        Credentials('', '', IMAGEX_SERVICE_NAME, REGION_US_EAST1),
        10, 10, "https"),
}

api_info = {
    # 模板管理
    "CreateImageTemplate":
        ApiInfo("POST", "/", {"Action": "CreateImageTemplate",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteImageTemplate":
        ApiInfo("POST", "/", {"Action": "DeleteImageTemplate",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "PreviewImageTemplate":
        ApiInfo("POST", "/", {"Action": "PreviewImageTemplate",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageTemplate":
        ApiInfo("GET", "/", {"Action": "GetImageTemplate",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetAllImageTemplates":
        ApiInfo("GET", "/", {"Action": "GetAllImageTemplates",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    # 资源管理相关
    "ApplyImageUpload":
        ApiInfo("GET", "/", {"Action": "ApplyImageUpload",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "CommitImageUpload":
        ApiInfo("POST", "/", {"Action": "CommitImageUpload",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "DeleteImageUploadFiles":
        ApiInfo("POST", "/", {"Action": "DeleteImageUploadFiles",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "UpdateImageUploadFiles":
        ApiInfo("POST", "/", {"Action": "UpdateImageUploadFiles",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "PreviewImageUploadFile":
        ApiInfo("GET", "/", {"Action": "PreviewImageUploadFile",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUploadFile":
        ApiInfo("GET", "/", {"Action": "GetImageUploadFile",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUploadFiles":
        ApiInfo("GET", "/", {"Action": "GetImageUploadFiles",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageUpdateFiles":
        ApiInfo("GET", "/", {"Action": "GetImageUpdateFiles",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageOCR":
        ApiInfo("POST", "/", {"Action": "GetImageOCR",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetSegmentImage":
        ApiInfo("POST", "/", {"Action": "GetSegmentImage",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageQuality":
        ApiInfo("POST", "/", {"Action": "GetImageQuality",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEraseModels":
        ApiInfo("GET", "/", {"Action": "GetImageEraseModels",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEraseResult":
        ApiInfo("POST", "/", {"Action": "GetImageEraseResult",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageEnhanceResult":
        ApiInfo("POST", "/", {"Action": "GetImageEnhanceResult",
                              "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageBgFillResult":
        ApiInfo("POST", "/", {"Action": "GetImageBgFillResult",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageComicResult":
        ApiInfo("POST", "/", {"Action": "GetImageComicResult",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageSuperResolutionResult":
        ApiInfo("POST", "/", {"Action": "GetImageSuperResolutionResult",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetImageSmartCropResult":
        ApiInfo("POST", "/", {"Action": "GetImageSmartCropResult",
                "Version": IMAGEX_API_VERSION}, {}, {}),
    "GetLicensePlateDetection":
        ApiInfo("POST", "/", {"Action": "GetLicensePlateDetection",
                "Version": IMAGEX_API_VERSION}, {}, {})
}


class Uploader:
    def __init__(self, host, store_infos=[], datas=[]):
        self.host = host
        self.store_infos = store_infos
        self.datas = datas

        self.queue = queue.Queue()
        self.queue_lock = threading.Lock()

        for i in range(len(store_infos)):
            self.queue.put(i)

    def async_upload(self):
        while not self.queue.empty():
            self.queue_lock.acquire()
            if self.queue.empty():
                self.queue_lock.release()
                break
            idx = self.queue.get()
            self.queue_lock.release()
            self.upload_by_host(idx)

    def upload_by_host(self, idx):
        store_info = self.store_infos[idx]
        img_data = self.datas[idx]
        url = 'http://{}/{}'.format(self.host, store_info['StoreUri'])
        check_sum = crc32(img_data) & 0xFFFFFFFF
        check_sum = "%08x" % check_sum
        headers = {'Content-CRC32': check_sum, 'Authorization': store_info['Auth']}
        upload_status, resp = ImageXService().put_data(url, img_data, headers)
        if not upload_status:
            raise Exception('upload by host: upload url %s status false, resp: %s' % (url, resp))


class ImageXService(Service):
    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = ImageXService.get_service_info(region)
        self.api_info = ImageXService.get_api_info()
        super(ImageXService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('ImageX not support region %s' % region)
        return service_info

    @staticmethod
    def get_api_info():
        return api_info

    # upload
    def apply_upload(self, params):
        res = self.get('ApplyImageUpload', params, doseq=1)
        if res == '':
            raise Exception("ApplyImageUpload: empty response")
        res_json = json.loads(res)
        return res_json

    def commit_upload(self, params, body):
        res = self.json('CommitImageUpload', params, body)
        if res == '':
            raise Exception("CommitImageUpload: empty response")
        res_json = json.loads(res)
        return res_json

    # upload local image file
    def upload_image(self, params, file_paths):
        img_datas = []
        for p in file_paths:
            if not os.path.isfile(p):
                raise Exception("no such file on file path %s" % p)
            in_file = open(p, "rb")
            img_datas.append(in_file.read())
            in_file.close()
        return self.upload_image_data(params, img_datas)

    # upload image data
    def upload_image_data(self, params, img_datas):
        for data in img_datas:
            if not isinstance(data, bytes):
                raise Exception("upload of non-bytes not supported")

        apply_upload_request = {
            'ServiceId': params['ServiceId'],
            'SessionKey': params.get('SessionKey', ''),
            'UploadNum': len(img_datas),
            'StoreKeys': params.get('StoreKeys', []),
        }
        resp = self.apply_upload(apply_upload_request)
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])

        result = resp['Result']
        reqid = result['RequestId']
        addr = result['UploadAddress']
        if len(addr['UploadHosts']) == 0:
            raise Exception("no upload host found, reqid %s" % reqid)
        elif len(addr['StoreInfos']) != len(img_datas):
            raise Exception("store info len %d != upload num %d, reqid %s" % (
                len(result['StoreInfos']), len(img_datas), reqid))

        session_key = addr['SessionKey']
        host = addr['UploadHosts'][0]
        self.do_upload(img_datas, host, addr['StoreInfos'])

        commit_upload_request = {
            'ServiceId': params['ServiceId'],
        }
        commit_upload_body = {
            'SessionKey': session_key,
            'Functions': params.get('Functions', []),
            'OptionInfos': params.get('OptionInfos', [])
        }
        resp = self.commit_upload(
            commit_upload_request, json.dumps(commit_upload_body))
        if 'Error' in resp['ResponseMetadata']:
            raise Exception(resp['ResponseMetadata'])
        return resp['Result']

    def do_upload(self, img_datas, host, store_infos):
        threads = []
        uploader = Uploader(host, store_infos, img_datas)
        for i in range(UPLOAD_THREADS):
            thread = threading.Thread(target=uploader.async_upload)
            thread.start()
            threads.append(thread)

        for i in range(UPLOAD_THREADS):
            threads[i].join()

    def get_upload_auth_token(self, params):
        apply_token = self.get_sign_url('ApplyImageUpload', params)
        commit_token = self.get_sign_url('CommitImageUpload', params)

        ret = {'Version': 'v1', 'ApplyUploadToken': apply_token,
               'CommitUploadToken': commit_token}
        data = json.dumps(ret)
        if sys.version_info[0] == 3:
            return base64.b64encode(data.encode('utf-8')).decode('utf-8')
        else:
            return base64.b64encode(data.decode('utf-8'))

    def get_upload_auth(self, service_ids, expire=60*60, key_ptn=''):
        apply_res = []
        commit_res = []
        if len(service_ids) == 0:
            apply_res.append(ResourceServiceIdTRN % '*')
            commit_res.append(ResourceServiceIdTRN % '*')
        else:
            for sid in service_ids:
                apply_res.append(ResourceServiceIdTRN % sid)
                commit_res.append(ResourceServiceIdTRN % sid)
        apply_res.append(ResourceStoreKeyTRN % key_ptn)

        inline_policy = Policy([
            Statement.new_allow_statement(
                ['ImageX:ApplyImageUpload'], apply_res),
            Statement.new_allow_statement(
                ['ImageX:CommitImageUpload'], commit_res)
        ])
        return self.sign_sts2(inline_policy, expire)

    def delete_images(self, service_id, uris):
        query = {
            'ServiceId': service_id
        }
        body = {
            'StoreUris': uris
        }
        res = self.json('DeleteImageUploadFiles', query, json.dumps(body))
        if res == '':
            raise Exception("DeleteImageUploadFiles: empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    # action=0: refresh
    # action=1: disable
    # action=2: enable
    def update_image_urls(self, service_id, urls, action=0):
        if action < 0 or action > 2:
            raise Exception("update action should be [0,2], %d" % action)

        query = {
            'ServiceId': service_id
        }
        body = {
            'Action': action,
            'ImageUrls': urls
        }
        res = self.json("UpdateImageUploadFiles", query, json.dumps(body))
        if res == '':
            raise Exception("UpdateImageUploadFiles: empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def get_image_info(self, service_id, store_uri):
        query = {
            'ServiceId': service_id,
            'StoreUri': store_uri,
        }
        res = self.get('PreviewImageUploadFile', query)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        if 'Error' in res_json['ResponseMetadata']:
            raise Exception(res_json['ResponseMetadata'])
        return res_json['Result']

    def imagex_get(self, action, params, doseq=0):
        res = self.get(action, params, doseq)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(json.dumps(res))
        return res_json

    def imagex_post(self, action, params, body):
        res = self.json(action, params, body)
        if res == '':
            raise Exception("%s: empty response" % action)
        res_json = json.loads(json.dumps(res))
        return res_json

    def get_image_ocr(self, params):
        res = self.post('GetImageOCR', params, {})
        if res == '':
            raise Exception("%s: empty response" % 'GetImageOCR')
        res_json = json.loads(res)
        return res_json

    def get_image_segment(self, params):
        res = self.post('GetSegmentImage', params, {})
        if res == '':
            raise Exception("%s: empty response" % 'GetSegmentImage')
        res_json = json.loads(res)
        return res_json

    def get_image_quality(self, params):
        body = {
            'ImageUrl': params['ImageUrl'],
            'VqType':  params.get('VqType', None)
        }
        res = self.imagex_post('GetImageQuality', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageQuality')
        res_json = json.loads(res)
        return res_json

    def get_image_erase_models(self, params):
        res = self.imagex_get('GetImageEraseModels', params)
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEraseModels')
        res_json = json.loads(res)
        return res_json

    def get_image_erase_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'BBox': params.get('BBox', None)
        }
        res = self.imagex_post('GetImageEraseResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEraseResult')
        res_json = json.loads(res)
        return res_json

    def get_image_enhance_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'DisableAr': params.get('DisableAr', None),
            'DisableSharp': params.get('DisableSharp', None),
            'Resolution': params.get('Resolution', None)
        }
        res = self.imagex_post('GetImageEnhanceResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageEnhanceResult')
        res_json = json.loads(res)
        return res_json

    def get_image_bg_fill_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Model': params['Model'],
            'Top': params.get('Top', None),
            'Bottom': params.get('Bottom', None),
            'Left': params.get('Left', None),
            'Right': params.get('Right', None)
        }
        res = self.imagex_post('GetImageBgFillResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageBgFillResult')
        res_json = json.loads(res)
        return res_json

    def get_image_comic_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri']
        }
        res = self.imagex_post('GetImageComicResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageComicResult')
        res_json = json.loads(res)
        return res_json

    def get_image_super_resolution_result(self, params):
        body = {
            'ServiceId': params['ServiceId'],
            'StoreUri': params['StoreUri'],
            'Multiple': params.get('Multiple', None)
        }
        res = self.imagex_post('GetImageSuperResolutionResult', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetImageSuperResolutionResult')
        res_json = json.loads(res)
        return res_json

    def get_license_plate_detection(self, params):
        body = {
            'ImageUri': params['ImageUri']
        }
        res = self.imagex_post('GetLicensePlateDetection', params, json.dumps(body))
        if res == '':
            raise Exception("%s: empty response" % 'GetLicensePlateDetection')
        res_json = json.loads(res)
        return res_json


# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')
    sts2 = vod_service.get_upload_sts2_with_expired_time(60 * 60)
    print(sts2)

    sts2 = vod_service.get_upload_sts2()
    print(sts2)



# coding:utf-8
from __future__ import print_function
from volcengine.rdspostgresql.rdspostgresql import RdsPostgreSQL


# test unit : "create_instance" "create_account" "create_white_list" "create_database" "modify_database_owner"
test_unit = "create_instance"
instanceID = "postgres-xxx"


def test_create_instance(cls):
    params = {
        "Region": "cn-north-x",
        "Zone": "cn-north-x-a",
        "DBEngine": "PostgreSQL",
        "DBEngineVersion": "PostgreSQL_12",       # PostgreSQL Version "PostgreSQL_12" "PostgreSQL_11"
        "InstanceType": "HA",                     # Primary isntance should be "HA" Readonly instance should be "Basic"
        "InstanceSpecName": "rds.postgres.1c2g",  # 1c2g mean 1CPU and 2G Memory
        "StorageSpaceGB": 100,                    # storage(GB)
        "Number": 1,                              # instance number
        "StorageType": "LocalSSD",                # storage type should be "LocalSSD"
        "VpcID": "vpc-xxx",
        "ChargeType": "PostPaid",                 # ChargeType currently should be "PostPaid"
        "InstanceCategory": "Primary",            # Primary instance type should be "Primary", readonly instance should be "ReadOnly"
        "RequestSource": "OpenAPI"
    }
    print(cls.create_instance(params))


def test_create_account(cls):
    params = {
        "InstanceId": instanceID,
        "AccountName": "user004",
        "AccountPassword": "xxx",
        "AccountDesc": "",
        "AccountType": "Normal",       # account type "Super" or "Normal"
    }
    print(cls.create_account(params))


def test_create_white_list(cls):
    params = {
        "InstanceId": instanceID,
        "GroupName": "hahaha",
        "IPList": ["1.1.1.2"],
    }
    print(cls.create_instance_white_list(params))


def test_create_database(cls):
    params = {
        "InstanceId":       instanceID,
        "DBName":           "db001",
        "CharacterSetName": "utf8",      # CharacterSet "utf8" "latin1" or "ascii"
        "Collate":          "CUTF8",     # Collate "C" "CUTF8" or "EnUsUtf8"
        "Ctype":            "CUTF8",     # Ctype "C" "CUTF8" or "EnUsUtf8"
        "Owner":            "user001",
    }
    print(cls.create_database(params))


def test_modify_database_owner(cls):
    params = {
        "InstanceId": instanceID,
        "DBName": "db001",
        "Owner": "user001",
    }
    print(cls.modify_database_owner(params))


if __name__ == '__main__':
    service = RdsPostgreSQL("cn-north-1")
    service.set_ak("Your AK")
    service.set_sk("Your SK")

    if test_unit == "create_instance":
        test_create_instance(service)
    elif test_unit == "create_account":
        test_create_account(service)
    elif test_unit == "create_white_list":
        test_create_white_list(service)
    elif test_unit == "create_database":
        test_create_database(service)
    elif test_unit == "modify_database_owner":
        test_modify_database_owner(service)



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetMediaInfosRequest, VodGetRecommendedPosterRequest, \
    VodUpdateMediaPublishStatusRequest, VodUpdateMediaInfoRequest, VodDeleteMediaRequest, VodDeleteTranscodesRequest, \
    VodGetMediaListRequest, VodCreateVideoClassificationRequest, VodUpdateVideoClassificationRequest, \
    VodDeleteVideoClassificationRequest, VodListVideoClassificationsRequest, VodListSnapshotsRequest

if __name__ == '__main__':
    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    # vod_service.set_ak('your ak')
    # vod_service.set_sk('your sk')

    try:
        vids = 'vid1,vid2'
        req = VodGetMediaInfosRequest()
        req.Vids = vids
        resp = vod_service.get_media_infos(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result)
        else:
            print(resp.ResponseMetadata.Error)
    print('*' * 100)

    try:
        vids = 'vid1,vid2'
        req2 = VodGetRecommendedPosterRequest()
        req2.Vids = vids
        resp2 = vod_service.get_recommended_poster(req2)
    except Exception:
        raise
    else:
        print(resp2)
        if resp2.ResponseMetadata.Error.Code == '':
            print(resp2.Result)
        else:
            print(resp2.ResponseMetadata.Error)

    print('*' * 100)

    try:
        vid = 'vid'
        status = 'Unpublished'
        req3 = VodUpdateMediaPublishStatusRequest()
        req3.Vid = vid
        req3.Status = status
        resp3 = vod_service.update_media_publish_status(req3)
    except Exception:
        raise
    else:
        print(resp3)
        if resp3.ResponseMetadata.Error.Code == '':
            print('update media publish status success')
        else:
            print(resp3.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req4 = VodUpdateMediaInfoRequest()
        req4.Vid = 'vid'
        req4.Title.value = 'title'
        req4.Description.value = 'description'
        req4.Tags.value = 'tag1,tag2'
        req4.ClassificationId.value = 0
        resp4 = vod_service.update_media_info(req4)
    except Exception:
        raise
    else:
        print(resp4)
        if resp4.ResponseMetadata.Error.Code == '':
            print('update media info success')
        else:
            print(resp4.ResponseMetadata.Error)

    print('*' * 100)

    try:
        vids = 'vid1,vid2'
        callBackArgs = 'CallBackArgs'
        req5 = VodDeleteMediaRequest()
        req5.Vids = vids
        req5.CallbackArgs = callBackArgs
        resp5 = vod_service.delete_media(req5)
    except Exception:
        raise
    else:
        print(resp5)
        if resp5.ResponseMetadata.Error.Code == '':
            print('delete media info success')
        else:
            print(resp5.ResponseMetadata.Error)

    print('*' * 100)

    try:
        vid = 'vid'
        fileIds = 'fileId1,fileId2'
        callBackArgs = 'CallBackArgs'
        req6 = VodDeleteTranscodesRequest()
        req6.Vid = vid
        req6.FileIds = fileIds
        req6.CallbackArgs = callBackArgs
        resp6 = vod_service.delete_transcodes(req6)
    except Exception:
        raise
    else:
        print(resp6)
        if resp6.ResponseMetadata.Error.Code == '':
            print('delete transcodes info success')
        else:
            print(resp6.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req7 = VodGetMediaListRequest()
        req7.SpaceName = 'your space name'
        req7.Vid = 'your vid'
        req7.Status = 'Published'  #Published/Unpublished
        req7.Order = 'Desc'        #Desc/Asc
        req7.StartTime = '1999-01-01T00:00:00Z'
        req7.EndTime = '2021-04-01T00:00:00Z'
        req7.Offset = '0'
        req7.PageSize = '10'
        req7.ClassificationId = 1
        resp7 = vod_service.get_media_list(req7)
    except Exception:
        raise
    else:
        print(resp7)
        if resp7.ResponseMetadata.Error.Code == '':
            print(resp7.Result)
        else:
            print(resp7.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req8 = VodCreateVideoClassificationRequest()
        req8.SpaceName = 'your space'
        req8.Level = 1
        req8.ParentId = 0
        req8.Classification = 'your classification'
        resp8 = vod_service.create_video_classification(req8)
    except Exception:
        raise
    else:
        print(resp8)
        if resp8.ResponseMetadata.Error.Code == '':
            print(resp8.Result)
        else:
            print(resp8.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req9 = VodUpdateVideoClassificationRequest()
        req9.SpaceName = 'your space'
        req9.ClassificationId = 0
        req9.Classification = 'your classification'
        resp9 = vod_service.update_video_classification(req9)
    except Exception:
        raise
    else:
        print(resp9)
        if resp9.ResponseMetadata.Error.Code == '':
            print(resp9.Result)
        else:
            print(resp9.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req10 = VodDeleteVideoClassificationRequest()
        req10.SpaceName = 'your space'
        req10.ClassificationId = 0
        resp10 = vod_service.delete_video_classification(req10)
    except Exception:
        raise
    else:
        print(resp10)
        if resp10.ResponseMetadata.Error.Code == '':
            print(resp10.Result)
        else:
            print(resp10.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req11 = VodListVideoClassificationsRequest()
        req11.SpaceName = 'your space'
        req11.ClassificationId = 0
        resp11 = vod_service.list_video_classifications(req11)
    except Exception:
        raise
    else:
        print(resp11)
        if resp11.ResponseMetadata.Error.Code == '':
            print(resp11.Result)
        else:
            print(resp11.ResponseMetadata.Error)

    print('*' * 100)

    try:
        req12 = VodListSnapshotsRequest()
        req12.Vid = "your vid"
        resp12 = vod_service.list_snapshots(req12)
    except Exception:
        raise
    else:
        print(resp12)
        if resp12.ResponseMetadata.Error.Code == '':
            print(resp12.Result)
        else:
            print(resp12.ResponseMetadata.Error)

    print('*' * 100)



class Function:
    @staticmethod
    def get_meta_func():
        return {'Name': 'GetMeta'}

    @staticmethod
    def get_snapshot_func(snapshot_time):
        return {'Name': 'Snapshot', 'Input': {'SnapshotTime': snapshot_time}}

    @staticmethod
    def get_add_option_info_func(title, tags, description, classification_id):
        return {'Name': 'AddOptionInfo', 'Input': {'Title': title, 'Tags': tags, 'Description': description,
                                                   'ClassificationId': classification_id}}

    @staticmethod
    def get_add_material_option_info_func(title, tags, description, category, record_type, format_input):
        return {'Name': 'AddOptionInfo',
                'Input': {'Title': title, 'Tags': tags, 'Description': description, 'Category': category,
                          'RecordType': record_type, 'Format': format_input}}

    @staticmethod
    def get_start_workflow_func(template_id):
        return {'Name': 'StartWorkflow', 'Input': {'TemplateId': template_id}}

    @staticmethod
    def get_encryption_func(conf, policy):
        return {'Name': 'Encryption', 'Input': {'Config': conf, 'PolicyParams': policy}}



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodUrlUploadRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space'
    url = 'url'

    try:
        req = VodUrlUploadRequest()
        req.SpaceName = space_name
        url_set = req.URLSets.add()
        url_set.SourceUrl = url
        resp = vod_service.upload_media_by_url(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data[0].JobId)
            print(resp.Result.Data[0].SourceUrl)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)



# coding:utf-8
import json
import threading

from retry import retry

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.ServiceInfo import ServiceInfo
from volcengine.base.Service import Service


class SecretNumberService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(SecretNumberService, "_instance"):
            with SecretNumberService._instance_lock:
                if not hasattr(SecretNumberService, "_instance"):
                    SecretNumberService._instance = object.__new__(cls)
        return SecretNumberService._instance

    def __init__(self, region='cn-north-1'):
        self.service_info = SecretNumberService.get_service_info(region)
        self.api_info = SecretNumberService.get_api_info()
        self.domain_cache = {}
        self.fallback_domain_weights = {}
        self.update_interval = 10
        self.lock = threading.Lock()
        super(SecretNumberService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(region):
        service_info_map = {
            'cn-north-1': ServiceInfo("cloud-vms.volcengineapi.com", {'Accept': 'application/json'},
                                      Credentials('', '', 'volc_secret_number', 'cn-north-1'), 10, 10),
        }
        service_info = service_info_map.get(region, None)
        if not service_info:
            raise Exception('Cant find the region, please check it carefully')

        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "BindAXB": ApiInfo("POST", "/", {"Action": "BindAXB", "Version": "2020-09-01"}, {}, {}),
            "SelectNumberAndBindAXB": ApiInfo("POST", "/",
                                              {"Action": "SelectNumberAndBindAXB", "Version": "2020-09-01"}, {}, {}),
            "UnbindAXB": ApiInfo("POST", "/", {"Action": "UnbindAXB", "Version": "2020-09-01"}, {}, {}),
            "QuerySubscription": ApiInfo("POST", "/", {"Action": "QuerySubscription", "Version": "2020-09-01"}, {}, {}),
            "QuerySubscriptionForList": ApiInfo("POST", "/",
                                                {"Action": "QuerySubscriptionForList", "Version": "2020-09-01"}, {},
                                                {}),
            "UpgradeAXToAXB": ApiInfo("POST", "/", {"Action": "UpgradeAXToAXB", "Version": "2020-09-01"}, {}, {}),
            "UpdateAXB": ApiInfo("POST", "/", {"Action": "UpdateAXB", "Version": "2020-09-01"}, {}, {}),
            "BindAXN": ApiInfo("POST", "/", {"Action": "BindAXN", "Version": "2020-09-01"}, {}, {}),
            "UpdateAXN": ApiInfo("POST", "/", {"Action": "UpdateAXN", "Version": "2020-09-01"}, {}, {}),
            "UnbindAXN": ApiInfo("POST", "/", {"Action": "UnbindAXN", "Version": "2020-09-01"}, {}, {}),
            "Click2Call": ApiInfo("POST", "/", {"Action": "Click2Call", "Version": "2021-09-01"}, {}, {}),
            "Click2CallLite": ApiInfo("POST", "/", {"Action": "Click2CallLite", "Version": "2021-09-01"}, {}, {}),
        }
        return api_info

    def common_handler(self, api, form):
        params = dict()
        try:
            res = self.post(api, params, form)
            res_json = json.loads(res)
            return res_json
        except Exception as e:
            res = str(e)
            try:
                res_json = json.loads(res)
                return res_json
            except:
                raise Exception(str(e))

    @retry(tries=2, delay=0)
    def bind_axb(self, form):
        try:
            return self.common_handler("BindAXB", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def select_number_and_bind_axb(self, form):
        try:
            return self.common_handler("SelectNumberAndBindAXB", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def unbind_axb(self, form):
        try:
            return self.common_handler("UnbindAXB", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def query_subscription(self, form):
        try:
            return self.common_handler("QuerySubscription", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def query_subscription_for_list(self, form):
        try:
            return self.common_handler("QuerySubscriptionForList", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def upgrade_ax_to_axb(self, form):
        try:
            return self.common_handler("UpgradeAXToAXB", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def update_axb(self, form):
        try:
            return self.common_handler("UpdateAXB", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def bind_axn(self, form):
        try:
            return self.common_handler("BindAXN", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def update_axn(self, form):
        try:
            return self.common_handler("UpdateAXN", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def unbind_axn(self, form):
        try:
            return self.common_handler("UnbindAXN", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def click2_call(self, form):
        try:
            return self.common_handler("Click2Call", form)
        except Exception as e:
            raise Exception(str(e))

    @retry(tries=2, delay=0)
    def click2_call_lite(self, form):
        try:
            return self.common_handler("Click2CallLite", form)
        except Exception as e:
            raise Exception(str(e))



from volcengine.livesaas.LivesaasService import LivesaasService

if __name__ == '__main__':
    livesaasService = LivesaasService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    livesaasService.set_ak('AK')
    livesaasService.set_sk('SK')

    body = {
        'ActivityId': 1,
        'LineId': 0,
        'PullStreamUrl': "",
        'PullStreamStatus': 1,
        'PullStreamMode': 0,
        'PullStreamLineId': 0,
        'PullStreamMainBackupMode': 0
    }

    resp = livesaasService.update_pull_to_push_api(body)
    # resp = await livesaasService.async_update_pull_to_push_api(body)
    print(resp)



# coding:utf-8

from volcengine.notify.notify import NotifyService

if __name__ == '__main__':
    notify_service = NotifyService()

    notify_service.set_ak("your ak")
    notify_service.set_sk("your sk")

    body = {
        "Url": "公网url，使用前需要申请正向代理",
        "Name": "测试文件"
    }

    notify_service.fetch_resource(body)



# coding:utf-8
from __future__ import print_function
from volcengine.imagex.ImageXService import ImageXService

if __name__ == '__main__':
    imagex_service = ImageXService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    imagex_service.set_ak('ak')
    imagex_service.set_sk('sk')

    params = dict()
    params['ServiceId'] = 'imagex service id'

    file_paths = ['image file path 1']
    resp = imagex_service.upload_image(params, file_paths)
    print(resp)

    img_datas = ['image data 1']
    resp = imagex_service.upload_image_data(params, img_datas)
    print(resp)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    select_number_and_bind_axb_form = {
        "NumberPoolNo": "NP161156328504091435",
        "PhoneNoA": "13700000001",
        "PhoneNoB": "13700000002",
        "ExpireTime": "1632920195",
    }
    print(secretNumberService.select_number_and_bind_axb(select_number_and_bind_axb_form))



# coding:utf-8

from volcengine.live.LiveService import LiveService

if __name__ == '__main__':
    live_service = LiveService()
    ak = ""
    sk = ""
    live_service.set_ak(ak)
    live_service.set_sk(sk)
    body = {
        "Domain": "domain",
        "SceneType": "push",
        "AuthDetailList": [
            {
                "EncryptionAlgorithm": "md5",
                "SecretKey": "xx",
            },
        ],
    }
    resp = live_service.update_auth_key(body)
    print(resp)



#  -*- coding: utf-8 -*-
from __future__ import print_function

from volcengine.nlp.NLPService import NLPService

if __name__ == '__main__':
    nlp_service = NLPService()

    # call below method if you dont set ak and sk in $HOME/.volc/config
    nlp_service.set_ak('ak')
    nlp_service.set_sk('sk')

    params = dict()

    form = {
        "request_type": "text",
        "title": "外交部：中方已同意并愿意安排欧盟及成员国驻华使节访问新疆",
        "content": "9月15日，外交部发言人汪文斌主持例行记者会。有记者提问，欧方表示，在9月14日举行的中德欧领导人视频会晤中双方谈及了人权、涉疆、香港等问题，欧方向中方表明了有关关切。中方对此有何评论？汪文斌表示，中方已就昨天举行的中德欧领导人会晤发布了详细的新闻稿。关于人权问题，习近平主席强调，世界上没有放之四海而皆准的人权发展道路，人权保障没有最好，只有更好。各国首先应该做好自己的事情。相信欧方能够解决好自身存在的人权问题。中方不接受人权“教师爷”、反对搞“双重标准”。中方愿同欧方本着相互尊重的原则加强交流，共同进步。会上还讨论了欧盟内部存在的人权问题，如难民问题久拖不决、人道主义危机屡屡上演，一些欧盟成员国种族主义、极端主义、少数族裔问题抬头，反犹太、反穆斯林、反黑人等言论和恶性事件频频发生等等。欧方坦承自身存在的问题，希望同中方本着平等和尊重的原则开展对话，增进相互了解，妥善处理差异和分歧。习近平主席还阐明了中方在涉港、涉疆问题上的原则立场，指出涉港、涉疆问题的实质是维护中国国家主权、安全和统一，保护各族人民安居乐业的权利。中方坚决反对任何人、任何势力在中国制造不稳定、分裂和动乱，坚决反对任何国家干涉中国内政。汪文斌指出，在涉疆问题上，我们一直欢迎包括欧方在内的各国朋友去新疆走一走、看一看，了解新疆的真实情况，而不是道听途说，偏信那些刻意编造的谎言。欧盟及成员国驻华使节提出希望访问新疆，中方已经同意并愿作出安排。现在球在欧方一边。同时我要说明一点，我们反对有罪推定式的调查。"
    }

    resp = nlp_service.keyphrase_extraction_extract(form)
    print(resp)



#  -*- coding: utf-8 -*-
import datetime

from volcengine.example.cdn import ak, sk
from volcengine.cdn.service import CDNService

if __name__ == '__main__':
    svc = CDNService()
    svc.set_ak(ak)
    svc.set_sk(sk)

    body = {
        'Domain': 'example.com',
        'ServiceType': 'web',
        'Origin': [
            {
                'OriginAction': {
                    'OriginLines': [{
                        'OriginType': 'primary',
                        'InstanceType': 'ip',
                        'Address': '1.1.1.1',
                        'HttpPort': '80',
                        'HttpsPort': '443',
                        'Weight': '100'
                    }]
                }
            }
        ],
        'OriginProtocol': 'HTTP'
    }

    resp = svc.add_cdn_domain(body)
    print(resp)



# coding:utf-8
from __future__ import print_function

from volcengine.imp.ImpService import ImpService
from volcengine.imp.models.business.imp_common_pb2 import InputPath
from volcengine.imp.models.request.request_imp_pb2 import *

if __name__ == '__main__':
    imp_service = ImpService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    imp_service.set_ak('your ak')
    imp_service.set_sk('your sk')

    # RetrieveJob
    try:
        req = ImpRetrieveJobRequest()
        req.JobIds.extend(['your JobId1', 'your JobId2'])
        resp = imp_service.retrieve_job(req)
    except Exception:
        raise
    else:
        print("resp:\n ", resp)
        if resp.ResponseMetadata.Error.Code == '':
            print("Result:\n ", resp.Result)
        else:
            print(resp.ResponseMetadata.Error)



# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo


class IamService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(IamService, "_instance"):
            with IamService._instance_lock:
                if not hasattr(IamService, "_instance"):
                    IamService._instance = object.__new__(cls)
        return IamService._instance

    def __init__(self):
        self.service_info = IamService.get_service_info()
        self.api_info = IamService.get_api_info()
        super(IamService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info():
        service_info = ServiceInfo("open.volcengineapi.com", {'Accept': 'application/json'},
                                   Credentials('', '', 'iam', 'cn-north-1'), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {"ListUsers": ApiInfo("GET", "/", {"Action": "ListUsers", "Version": "2018-01-01"}, {}, {})}
        return api_info

    def list_users(self, params):
        res = self.get("ListUsers", params)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)
        return res_json



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodApplyUploadInfoRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    space_name = 'your space'

    try:
        req = VodApplyUploadInfoRequest()
        req.SpaceName = space_name

        resp = vod_service.apply_upload_info(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.UploadAddress.StoreInfos[0].StoreUri)
            print(resp.Result.Data.UploadAddress.StoreInfos[0].Auth)
            print(resp.Result.Data.UploadAddress.UploadHosts[0])
            print(resp.Result.Data.UploadAddress.SessionKey)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)




# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodQueryUploadTaskInfoRequest

if __name__ == '__main__':
    vod_service = VodService()

    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')

    jobId = 'url jobId'

    jobIds = [jobId]
    comma = ','
    s = comma.join(jobIds)

    req = VodQueryUploadTaskInfoRequest()
    req.JobIds = s
    try:
        resp = vod_service.query_upload_task_info(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.Data)
            print(resp.Result.Data.MediaInfoList[0].State)
        else:
            print(resp.ResponseMetadata.Error)
            print(resp.ResponseMetadata.RequestId)



# coding:utf-8
from __future__ import print_function

from volcengine.vod.VodService import VodService
from volcengine.vod.models.request.request_vod_pb2 import VodGetPlayInfoWithLiveTimeShiftSceneRequest

if __name__ == '__main__':
    vod_service = VodService()
    # call below method if you dont set ak and sk in $HOME/.vcloud/config
    vod_service.set_ak('your ak')
    vod_service.set_sk('your sk')
    try:
        req = VodGetPlayInfoWithLiveTimeShiftSceneRequest()
        req.StoreUris = 'uri1,uri2,uri3'
        req.SpaceName = 'your space name'
        req.Ssl = '0 or 1'
        req.ExpireTimestamp = 'unix timestamp'
        req.NeedComposeBucketName = '0 or 1'
        resp = vod_service.get_play_info_with_live_time_shift_scene(req)
    except Exception:
        raise
    else:
        print(resp)
        if resp.ResponseMetadata.Error.Code == '':
            print(resp.Result.PlayInfoList[0].MainPlayUrl)
        else:
            print(resp.ResponseMetadata.Error)
    print('*' * 100)



# coding:utf-8
from volcengine.secretnumber.SecretNumberService import SecretNumberService

if __name__ == '__main__':
    secretNumberService = SecretNumberService()

    secretNumberService.set_ak("")
    secretNumberService.set_sk("")

    update_axb_form = {
        "NumberPoolNo": "NP161156328504091435",
        "SubId": "S1632900399315954ffbfd",
        "UpdateType": "updateExpireTime",
        "ExpireTime": "1632923795",
    }
    print(secretNumberService.update_axb(update_axb_form))



# coding: utf-8
import datetime

from volcengine.auth.SignerV4 import SignerV4
from volcengine.auth.SignParam import SignParam
from volcengine.Credentials import Credentials
from collections import  OrderedDict

if __name__ == '__main__':
    sign = SignerV4()

    param = SignParam()
    param.path = '/'
    param.method = 'GET'
    param.host = 'open.volcengineapi.com'
    param.body = ''
    param.date = datetime.datetime.utcfromtimestamp(1640712206)
    query = OrderedDict()
    query['Action'] = 'ListUsers'
    query['Version'] = '2018-01-01'
    query['Limit'] = '5'
    query['Offset'] = '0'

    param.query = query
    header = OrderedDict()
    header['Host'] = 'open.volcengineapi.com'
    param.header_list = header

    cren = Credentials('ak','sk', 'iam', 'cn-north-1')
    result = sign.sign_only(param, cren)

    print(result)


# coding:utf-8
import json
import threading

from volcengine.ApiInfo import ApiInfo
from volcengine.Credentials import Credentials
from volcengine.base.Service import Service
from volcengine.ServiceInfo import ServiceInfo
from volcengine.const.Const import *
from retry import retry


class SmsService(Service):
    _instance_lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        if not hasattr(SmsService, "_instance"):
            with SmsService._instance_lock:
                if not hasattr(SmsService, "_instance"):
                    SmsService._instance = object.__new__(cls)
        return SmsService._instance

    def __init__(self, region=REGION_CN_NORTH1):
        self.service_info = SmsService.get_service_info(self, region)
        self.api_info = SmsService.get_api_info()
        super(SmsService, self).__init__(self.service_info, self.api_info)

    @staticmethod
    def get_service_info(self, region):
        if region == REGION_AP_SINGAPORE1:
            service_info = ServiceInfo("sms.byteplusapi.com", {'Accept': 'application/json'},
                                       Credentials('', '', 'volcSMS', region), 5, 5)
        else:
            service_info = ServiceInfo("sms.volcengineapi.com", {'Accept': 'application/json'},
                                       Credentials('', '', 'volcSMS', region), 5, 5)
        return service_info

    @staticmethod
    def get_api_info():
        api_info = {
            "SendSms": ApiInfo("POST", "/", {"Action": "SendSms", "Version": "2020-01-01"}, {}, {}),
            "SendSmsVerifyCode": ApiInfo("POST", "/", {"Action": "SendSmsVerifyCode", "Version": "2020-01-01"}, {}, {}),
            "CheckSmsVerifyCode": ApiInfo("POST", "/", {"Action": "CheckSmsVerifyCode", "Version": "2020-01-01"}, {}, {}),
        }
        return api_info

    @retry(tries=2, delay=0)
    def send_sms(self, body):
        res = self.json('SendSms', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    def send_sms_verify_code(self, body):
        res = self.json('SendSmsVerifyCode', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json

    def check_sms_verify_code(self, body):
        res = self.json('CheckSmsVerifyCode', {}, body)
        if res == '':
            raise Exception("empty response")
        res_json = json.loads(res)

        return res_json